/*------------------------------------------------------------------------------
  ------------------------------------------------------------------------------
  Skopek & Leopold (2017). 
  Who becomes a Grandparent – And When? Educational Differences in the Chances 
  and Timing of Grandparenthood.
  In: Demographic Research. 

  Preparation of the original survey data of the Germany Ageing Survey 2008 
  which is published by the research data center of the DZA ('Deutsches Zentrum 
  für Altersfragen', German Centre of Gerontology).
  
  We used Scientific Use File Deutscher Alterssurvey (SUF DEAS) 2008, Version 2.0,
  DOI: 10.5156/DEAS.2008.M.002
  
  Documentation on the German Ageing Survey can be found here: 
  
  http://www.dza.de/fdz/deutscher-alterssurvey.html (english pages available)
  
  Engstler, H. and A. Motel-Klingebiel (2010). Datengrundlagen und 
		Methoden des Deutschen Alterssurveys (DEAS). In: Motel-Klingebiel, A., 
		Wurm, S., and Tesch-Römer, C. (eds), Altern im Wandel. Befunde des Deutschen 
		Alterssurveys (DEAS). Stuttgart: Kohlhammer, S. 34-60.
		
  Mahne, K. and  H. Engstler (2010). Deutscher Alterssurvey (DEAS). 
		Kurzbeschreibung des Datensatzes DEAS2008 Version 2.
		
  Motel-Klingebiel, A. et al. (2010). GERMAN AGEING SURVEY (DEAS): THE SECOND 
		HALF OF LIFE. Research Instruments of the Third Wave. German Centre of 
		Gerontology. http://www.dza.de/fileadmin/dza/pdf/Diskussionspapier_Nr_52.pdf

  
  Note: The original scientific use file contains coarsed and categorized dates 
		for birth of children and grandchildren for reasons of disclosure control. 
		However, a correct estimation of timing of grandparenthood requires very 
		precise data. Hence, for the purpose of our study, we obtained the 
		original values for date of birth variables from the data center of 
		the DZA. 

  Output file: 00_prepare.dta
  
------------------------------------------------------------------------------
------------------------------------------------------------------------------*/

set more off

// config 
run config

* load original SUF data file
use "${sufdata}", clear

/*-----------------------------------------
  Restrict to cross-section 2008. 
-----------------------------------------*/

// Restriction to cross-sectional sample in 2008 (Basisstichprobe B2008)
keep if stich==3


/*-----------------------------------------
  Recover original birth data. 
-----------------------------------------*/

// The original scientific use file contains coarsed and categorized dates for birth 
// of children and grandchildren for reasons of disclosure control. 
// This could blur even flaw our investigation of timing to grandparenthood. 
// For the purpose of our study, we obtained from the data center of the DZA 
// the original not manipulated date of birth variables. 

// Note: variable "fallnum" is the person identifier. 

// Replace not-anonymized birth dates. 
* 1) load add-on data (original birth dates)
preserve 
	use "${sufdata_birthdates}", clear
	// remove data from previous samples
	merge 1:1 fallnum using "${sufdata}", assert(match) keepusing(stich)
	keep if stich==3
	
	renvars x3041-x316d28o, pref(EXACT_)
	tempfile exact
	save `exact'
restore
* 2) merge add-on data
merge 1:1 fallnum  using `exact', nogen

* 3) replace anonymized birth date data with exact data
* (child 1-4)
foreach var of varlist x3041 x3042 x3043 x3044 {
	order EXACT_`var', before(`var') 
	rename `var'  __`var' 
	rename EXACT_`var' `var'
}
* (child 5-8)
foreach num of numlist 5/8 {
	rename EXACT_x304`num' x304`num'
	order x304`num', before(x304`num'kat)
	drop x304`num'kat
}

* "Single" grandkids ("Einzelenkel", uncategorized variables)
foreach var of varlist x316d1? x316d2?? {
	order EXACT_`var', before(`var') 
	rename `var'  __`var' 
	rename EXACT_`var' `var'
}

* "Einzelenkel", "Basisenkel" (categorized variables)
* replace categorized variables by original variables 
* d x316d1? x316d1?kat x316d2?*
foreach var of varlist x316???kat x316????kat {
	local name: subinstr local var "kat" ""
	di "`name'"
	if "`name'" != "`var'" {
		gen `name' = EXACT_`name'
		order `name', before(`var')
		local label: variable label `var'
		local label: subinstr local label ", kategorisiert" ""
		lab var `name' "`label'"
		drop `var'
	} 
	drop EXACT_`name'
}

* Remainder
order EXACT_x316d21k-EXACT_x316d21o, after(x316g21j)
renvars EXACT_x316d21k-EXACT_x316d21o, subst("EXACT_" "")
order __*, last

drop __*


/*-----------------------------------------
  Prepare child and grandchild data. 
  All children and all grandchildren. 
-----------------------------------------*/

// Note: 
// If a child has only one child ("Einzelenkel") full information is collected on that grand child. 
// If a child has more than one child basic information like gender and date of birth is collected 
// for every child of child ("Basisenkel"), but one child of child is selected by random for extended 
// questions ("Zufallsenkel"). Even if we are only interested in the basic grandchild data this has to be
// kept in mind for the preparation. 

// Prepare child data first. 
preserve 
	// restrict to child data 
	keep fallnum stich x300 x3011-x316j
	drop x316j
	keep fallnum x300 x301? x302? x303? x303a? x303b? x304? ///
				 x304a? x305? x306? x307? x308? x309? x311? /// 
				 x311a? x312? x313? x314? x315?kat x316? x316a?
	// child data is stored in wide format. Convert to long format in order to facilitate the preparation. 
	* modify labels
	foreach stub in x301@ x302@ x303@ x303a@ x303b@ x304@ x304a@ x305@ x306@ x307@ x308@ x309@ x311@ x311a@ x312@ x313@ x314@ x315@kat x316@ x316a@ {
		local name: subinstr local stub "@" "", all
		local var: subinstr local stub "@" "1", all
		local lab: variable label `var'  
		local lab`name' "`lab'"
		local lab`name': subinstr local lab`name' "1." "", all
		local val: value label `var'
		local val`name' "`val'"
	}
	
	* reshape to long
	reshape long x301@ x302@ x303@ x303a@ x303b@ x304@ x304a@ x305@ x306@ x307@ x308@ x309@ x311@ x311a@ x312@ x313@ x314@ x315@kat x316@ x316a@, i(fallnum) j(kind)
	
	* adjust labels  
	foreach var of varlist x301-x313 {
		lab var `var' "`lab`var''"
		lab val `var' `val`var''
	}

	* drop skipped items (if there was no further child)
	drop if x301==-1

	* decode missing values to stata missings	
	mvdecode x303 x303a x303b, mv(-1=.a \ 7/9=.a)

	* mark biological children
	gen bio = .
	replace bio = 1 if inlist(x303,1,2)
	replace bio = 1 if inlist(x303a,2)
	replace bio = 1 if inlist(x303b,2)


	* decode missing values in year of birth of child 
	mvdecode x304, mv(9997/9998=.a)
	
	* save children data ("kinder")
	save "${prepared}/kinder", replace
restore


// Prepare grandkid data: "Einzelenkel" (children with only one child). 
preserve
	* keep only variables for "Einzelenkel" ('single grandkids')
	keep fallnum stich x316b? x316c1? x316d1* x316d1? x316e1? x316f1? x316g1? 

	// Data si in wide format. Convert to long format. 
	* adjust labels
	foreach stub in x316b@ x316c1@ x316d1@ x316e1@ x316f1@ x316g1@ {
		local name: subinstr local stub "@" "", all
		local var: subinstr local stub "@" "1", all
		local lab: variable label `var'  
		local lab`name' "`lab'"
		local lab`name': subinstr local lab`name' "1." "", all
		local val: value label `var'
		local val`name' "`val'"
	}
	
	* convert to long
	reshape long x316b@ x316c1@ x316d1@ x316e1@ x316f1@ x316g1@, i(fallnum) j(kind)
	
	* order variables
	order fallnum kind x316b x316c1 x316d1 x316e1 x316f1 x316g1 

	* adjust labels
	foreach var of varlist x316b-x316g1 {
		lab var `var' "`lab`var''"
		lab val `var' `val`var''
	}
		
	* drop skipped items (child has no kids) 
	//<// drop if x316b==-1
	drop if x316b == .c // "überfiltert"
	
	* decode missing values to stata missings
	mvdecode x316c1, mv(8=.a)	// old
	mvdecode x316d1, mv(9997/9999=.a) // old
	replace x316d1 = .a if x316d1== . // some few missings in birth of grandchild
	
	
	* mark grandkids as "Einzelenkel"
	gen einzelenk = 1
	
	* save prepared data for "Einzelenkel"
	save "${prepared}/einzelenkel", replace

restore

// Prepare grandkid data: "Basisenkel" (children with more than one child). 
preserve
	* restrict to relevant variables 
	keep fallnum stich x316b2* x316c2* x316d2* x316e2* x316g2* 
	
	// Data in wide format. Convert to long format. 
	snapshot save, label("basisenkel")

	* work through from 1st to 8th child (save each in a separate data set)
	foreach num of numlist 1/8 {
		di `num'
		tempfile basisenkel`num' 

		local vars x316b2`num'? x316c2`num'? x316d2`num'? x316e2`num'?  x316g2`num'?
		local stubs x316b2`num'@ x316c2`num'@ x316d2`num'@ x316e2`num'@  x316g2`num'@
		if `num' > 4 {
			local vars x316b2`num'? x316c2`num'? x316d2`num'? 
			local stubs x316b2`num'@ x316c2`num'@ x316d2`num'@
		}  
		keep fallnum `vars' 
		order fallnum `vars' 

		foreach stub in `stubs' {
			local name: subinstr local stub "@" "", all
			local var: subinstr local stub "@" "a", all
			local lab: variable label `var'  
			local lab`name' "`lab'"
			local lab`name': subinstr local lab`name' "1." "", all
			local val: value label `var'
			local val`name' "`val'"
		}
	
		* convert to long
		reshape long `stubs', i(fallnum) j(enkel) string
		
		* adjust labels
		foreach var of varlist x316*  {
			lab var `var' "`lab`var''"
			lab val `var' `val`var''
			* rename variables (remove last letter)
			renvars `var', postdrop(1)
		}

		drop enkel 
		clonevar enkel = x316b2
		//<// drop if enkel == -1 | enkel == . 
		// drop if enkel == -1 | enkel == .c | enkel == .
		drop if  enkel == -1  | enkel == .c | enkel == .
		drop x316b2
		gen kind = `num'
		gen basisenkel = 1
		order fallnum kind enkel

		save `basisenkel`num'', replace
		snapshot restore 1 
	}


	* append grandchild data from n'th child
	use `basisenkel1', clear
	foreach num of numlist 2/8 {
		append using `basisenkel`num''
	}

		* decode missing values
	mvdecode x316d2, mv(9997/9999=.a)
	//<// mvdecode x316c2, mv(7/8=.a)
	mvdecode x316c2, mv(7=.a \ 8=.b)

	isid fallnum kind enkel
	* save all "Basisenkel"
	save "${prepared}/basisenkel", replace
restore

// Add extended data on randomly selected "Basisenkel" ("Zufallsenkel") for the first 4 children. 

preserve 
	keep fallnum stich zekcode? x316f3? x316g3? x316h3? x316i3? 

	foreach stub in x316f3@ x316g3@ x316h3@ x316i3@ {
		local name: subinstr local stub "@" "", all
		local var: subinstr local stub "@" "1", all
		local lab: variable label `var'  
		local lab`name' "`lab'"
		local lab`name': subinstr local lab`name' "1." "", all
		local val: value label `var'
		local val`name' "`val'"
	}

	reshape long zekcode@ x316f3@ x316g3@ x316h3@ x316i3@, i(fallnum) j(kind)

	foreach var of varlist x316f3 x316g3 x316h3 x316i3 {
		lab var `var' "`lab`var''"
		lab val `var' `val`var''
	}
		
	drop if zekcode==-1 | zekcode == .c | zekcode == .f | zekcode == .

	rename zekcode enkel

	gen basisenkel = 1
	gen zufallsenkel = 1
	
	isid fallnum kind enkel

	tempfile zufallsenkel
	save `zufallsenkel' 

	* Merge extended data to "Basisenkel"
	use "${prepared}/basisenkel", clear
	merge 1:1 fallnum kind enkel using `zufallsenkel', assert(master match)
	drop _merge
	replace zufallsenkel = 0 if zufallsenkel==.

	save "${prepared}/basisenkel", replace
restore


* Rename variables and harmonize grandkid data. 
preserve 
	* rename variables for "Einzelenkel"
	use "${prepared}/einzelenkel", clear
	rename x316b enkel
	rename x316c1 geschl 
	rename x316d1 geburtsj
	rename x316e1 leibl 
	rename x316f1 inHH
	rename x316g1 wohnentf
	save "${prepared}/einzelenkel", replace

	* rename variables for "Basisenkel"
	use "${prepared}/basisenkel", clear
	capt drop x316b2
	rename x316c2 geschl 
	rename x316d2 geburtsj
	rename x316e2 inHH
	rename x316g2 wohnentf
	rename x316f3 leibl
	save "${prepared}/basisenkel", replace

	* Append both data sets. 
	use "${prepared}/einzelenkel", clear
	append using "${prepared}/basisenkel"

	* Sort by casenumber, child number, and grandchild number
	sort fallnum kind enkel

	* adjust labels
	foreach var of varlist enkel-wohnentf {
		local lab: variable label `var'
		local newlab: subinstr local lab "Einzelenkel: " "Enkel: ", all
		lab var `var' "`newlab'"
	}
	
	
	* save harmonized grandkid data
	save "${prepared}/enkel", replace
	
restore


/*-----------------------------------------
  Prepare data on biological children and 
  their children.
  Select only biological children with children. 
-----------------------------------------*/

// Note: "enkel" has a three-level long data structure. 
// Each record represents a grandchild. 
// Grandkids are nested in children who are nested in respondents. 

preserve 
	// Start with "Enkel" data. 
	// Flatten the grandchild level by converting grandchild data to wide.
	use "${prepared}/enkel", clear
	
	keep fallnum kind geburtsj
	
	mvdecode geburtsj, mv(9997/9999=.a)
	
	sort fallnum kind geburtsj
	
	rename geburtsj grchbyr
	
	by fallnum kind (grchbyr), sort: gen nofenkel = _N
	
	by fallnum kind (grchbyr), sort: gen n = _n
	
	reshape wide grchbyr, i(fallnum kind) j(n)

	tempfile enkel
	save `enkel' 

	// use children data. 
	use "${prepared}/kinder", clear
	
	* decode missings in child's year of birth. 
	mvdecode x304, mv(9997/9998=.a)
	
	sort fallnum x304
	
	rename x304 childbyr

	* decode missings
	mvdecode x309, mv(-1=. \ 7/8 = .a)	// child lives in household
	mvdecode x311, mv(9997/9998=.a \ -1=.)	// year child leaved homed

	recode x309 (1=1) (2=0), gen(resident)
	gen leaveyr = x311
	replace leaveyr = childbyr if leaveyr==9995 // if never lived together, take year of birth as year of leaving 

	keep fallnum kind childbyr bio resident leaveyr

	* add grandkid data to child data
	merge 1:1 fallnum kind using `enkel', assert(matched master)
	gen enkeldata = _merge==3
	drop _merge	

	* keep only biological children and their children
	keep if bio==1

	// for all biological children identify the oldest child 
	* bring whole data in wide format
	foreach var of varlist grchbyr* {
		rename `var' `var'_
	}
	rename enkeldata enkeldata_
	rename bio bio_
	rename kind kind_
	rename childbyr childbyr_
	rename resident resident_
	rename leaveyr leaveyr_
	rename nofenkel nofenkel_
	sort fallnum kind_
	ds grchbyr*_
	reshape wide childbyr_ `r(varlist)' bio_ enkeldata_ leaveyr_ resident_ nofenkel_, i(fallnum) j(kind_)

	* year of birth of first grandchild (= oldest grandchild)
	egen birth_ogc = rowmin(grchbyr*)
	replace birth_ogc = .a if (enkeldata_1==1 | enkeldata_2==1 | enkeldata_3==1 | enkeldata_4==1 ///
							 | enkeldata_5==1 | enkeldata_6==1 | enkeldata_7==1 | enkeldata_8==1) & birth_ogc==.

	* year of birth of first child (= oldest child) 
	egen birth_oc = rowmin(childbyr_*)
	replace birth_oc = .a if birth_oc == .
	
	* year of birth of youngest child
	egen birth_yc = rowmax(childbyr_*)
	replace birth_yc = .a if birth_yc == .

	* mark cases with children still at home
	egen chinHH = rowmax(resident_*)
	
	* year of last leaving home event
	egen lastleaveyr = rowmax(leaveyr_*)

	* marker for availability of child data
	gen kinddata = 1

	* marker for availability of grandchild data
	gen enkeldata = (enkeldata_1==1 | enkeldata_2==1 | enkeldata_3==1 | enkeldata_4==1 ///
			   | enkeldata_5==1 | enkeldata_6==1 | enkeldata_7==1 | enkeldata_8==1) 

	* save biological children with children		   
	save "${prepared}/biokindermitenkel", replace
restore


/*-----------------------------------------
  Prepare other variables based on the 
  original variables. 
-----------------------------------------*/

* number of children
mvdecode x300, mv(-1=. \ 97 99 = .a)
recode x300 (1/9 = 1) (95=0) (.a=.a), gen(kinder)

* sex
clonevar sex = x1

* year of birth
clonevar birth = x2_3

* ISCED
// < // mvdecode isced_08 isei88zp_08 , mv(-9=.a \ -1=.)
// isei88zp_08 does not exist any longer in the recent SUF data
mvdecode isced_08  , mv(-9=.a \ -1=.)

clonevar isced = isced_08



* East and West (code Berlin as "West Germany")
recode bland_08 (1/11 = 0 "West") (12/16=1 "Ost"), gen(ost)

* Lived in which part of Germany prior to reunification 
clonevar wherelived = x328
recode wherelived (1=1 "East") (2=2 "West") (else=.), gen(part)	

* one missing value in bland (recode to West)
li wherelived if bland_08==.
recode bland_08 (11 12 13 14 15 16 = 2) (.=1) (else=1), gen(part2008)

* Where grew up (until age of 16)
clonevar wheregrewup = x327

* item for number of children
clonevar nofchildren = x300

		
* age variable
gen age = alter_08 

/*-----------------------------------------
  Life course transitions:
  Parenting context  
-----------------------------------------*/

* add data on biological children and their kids
merge 1:1 fallnum using "${prepared}/biokindermitenkel", assert(master matched) nogen 

* generate variables for children's age
local i = 1 
foreach var of varlist childbyr* {
	gen  childage_`i' = intjahr - `var'
	local i = `i' + 1
}

* Count biological children
egen numbiochild = anycount(bio_*), value(1)
lab var numbiochild "Number of biological children"

* Count co-resident biol. children
egen numbiocoreschild = anycount(resident_*), value(1)
lab var numbiocoreschild "Number of co-resident biolog. children"

* Count children of biol. children
egen numbiochildenkel = rowtotal(nofenkel_*)
lab var numbiochildenkel "Number of grandchildren from biolog. children"
 

// transition to first parenthood (biolog.)
gen fchild = kinddata == 1
gen ttfchild = birth_oc - birth if fchild==1
replace ttfchild = .a if birth_oc == .a
replace ttfchild = intjahr - birth if fchild==0 
replace ttfchild = .d if ttfchild < 0
* age at first child 
replace ttfchild = .d if ttfchild < 12 & fchild==1


* at least 1 child age 16 at time of interview 
egen maxchage = rowmax(childage_*)
replace maxchage = .a if kinddata==1 & maxchage==.

* marker for at least one child age 16 or older at time of interview
gen sample_onechild16 = maxchage >= 16 if !mi(maxchage)

* alternatively: at least 1 child age 15 or older  at time of interview 
gen sample_onechild15 = maxchage >= 15 if !mi(maxchage)

* Age at time of first birth
gen ageochild = birth_oc - birth

* Age at time when oldest child is 14
gen ageochild14 = (birth_oc+14) - birth

* is a parent?
gen isparent = ageochild < .


/*-----------------------------------------
  Life course transitions:
  (3) Grandparenthood 
-----------------------------------------*/

gen desGPH = birth_ogc!=. // birth_ogc = .a => grandkid, but year of birth not known
gen durGPH = (birth_ogc - birth) if desGPH==1
replace durGPH = .a if desGPH==1 & durGPH==.

* set duration to age at interview for right censored cases
replace durGPH = (intjahr - birth) if desGPH==0

/*-----------------------------------------
  Save data
-----------------------------------------*/
save "${prepared}/00_prepare.dta", replace




