/*------------------------------------------------------------------------------
  ------------------------------------------------------------------------------
  Skopek & Leopold (2017). 
  Who becomes a Grandparent – And When? Educational Differences in the Chances 
  and Timing of Grandparenthood.
  In: Demographic Research. 
  
  Prepare some additional variables (on higher parity parenthood and grandparenthood). 
  Drop few inconsistent cases. Condition on valid grandparenthood data.  
  
  Output file: 02_Additional_Variables.dta
  
------------------------------------------------------------------------------
------------------------------------------------------------------------------*/

/*-----------------------------------------
  Prepare some additional data on higher parity 
  children and grandchildren
-----------------------------------------*/
/* Prepare data for grandparenthood parity */ 

// PREPARE variables for
// age at every grandchildren births
// needed for parity analyses

run config

use "${prepared}/01_sample", clear

drop if ttfchild >= .

assert fchild == isparent

drop if isparent==0 & desGPH == 1

keep if desGPH==1 // keep only grandparents

keep fallnum birth durGPH grchbyr* intjahr

renvars grchbyr*, subst("_" "")

reshape long grchbyr, i(fallnum) j(j)

drop if grchbyr == .

by fallnum (grchbyr), sort: gen totgc = _N

by fallnum (grchbyr), sort: gen n = _n

gen gcage = grchbyr - birth

drop j

rename grchbyr gcby

lab var gcby "GC birth year"

lab var gcage "GC R's age at birth"

expand 2 if n==totgc, gen(copy) // create a last censored episode for being at risk for the next grandchild

sort fallnum n copy

by fallnum (n), sort: replace n = _n

gen des = copy!=1

gen begin = birth 

gen end = gcby

// li in 1/30, sepby(fallnum)
by fallnum (n), sort: replace begin = end[_n-1] if _n>1

by fallnum (n), sort: replace end = intjahr if copy==1

rename n gpepi
lab var gpepi "Grandparenthood episode (transition to x grandchild)"

// add 6 months if end and begin do equal
by fallnum (gpepi), sort: replace end = end+.5 if begin==end

stset end if gpepi <=4, f(des) origin(begin)


keep fallnum gcage gpepi _d _t0 _t totgc durGPH

drop _t0 

rename _d desGPHnr

rename _t durGPHnr

reshape wide gcage desGPHnr durGPHnr, i(fallnum) j(gpepi)

assert durGPH == gcage1 if !mi(gcage1) // integrity check

assert durGPH == durGPHnr1 if !mi(gcage1) // integrity check

drop durGPH

lab var totgc "Total number of grandchildren"

tempfile gc
save `gc'


/* Prepare data for parenthood parity */ 

// PREPARE variables for
// age at every birth of own biological children
// needed for parity analyses

run config

use "${prepared}/01_sample", clear

drop if ttfchild >= .

assert fchild == isparent

drop if isparent==0 // restrict only to those who ever had children

keep fallnum birth ttfchild childbyr_* intjahr

// work in long format
reshape long childbyr_, i(fallnum) j(j)

sort fallnum j

drop if childbyr_==. // remove superfluous records
// now sort by year of child birth

sort fallnum childbyr_

// count children
by fallnum (childbyr_), sort: gen totc = _N

by fallnum (childbyr_), sort: gen n = _n

// calculate age at birth of child
gen cage = childbyr_ - birth

drop j

rename childbyr_ cby

lab var cby "C birth year"

lab var cage "C R's age at birth"

expand 2 if n==totc, gen(copy) // create a last censored episode for being at risk for the next child

sort fallnum n copy

by fallnum (n), sort: replace n = _n

gen des = copy!=1

gen begin = birth 

gen end = cby

by fallnum (n), sort: replace begin = end[_n-1] if _n>1

by fallnum (n), sort: replace end = intjahr if copy==1

rename n pepi
lab var pepi "Parenthood episode (transition to x child)"

// add 6 months if end and begin are equal
by fallnum (pepi), sort: replace end = end+.5 if begin==end

// define episodes up to fourth child
stset end if pepi <=4, f(des) origin(begin)

keep fallnum cage pepi _d _t0 _t totc ttfchild

drop _t0 

rename _d desPHnr

rename _t durPHnr

reshape wide cage desPHnr durPHnr, i(fallnum) j(pepi)

assert ttfchild == cage1 if !mi(cage1) // integrity check

assert ttfchild == durPHnr1 if !mi(cage1) // integrity check

drop ttfchild
lab var totc "Total number of children"

tempfile c
save `c'

/*-----------------------------------------
  Load sample and add higher parity data
-----------------------------------------*/

use "${prepared}/01_sample", clear

drop if ttfchild >= . // 11 obs
assert fchild == isparent 

// Drop inconsistent cases (not parent, but grandparent)
drop if isparent==0 & desGPH == 1 // 0 obs

// merge parity data on grandparenthood
merge 1:1 fallnum using `gc', assert(master matched) nogen

// merge parity data on parenthood
merge 1:1 fallnum using `c', assert(master matched) nogen


// take ISCED high as educational level (collapses on the higher end of the educational scale)
recode isced_08 (1 2 = 0 "low") (3 = 1 "higher"), gen(E)
drop if E >= . // 0 obs

// indicator for childlessness
gen childless = isparent==0 if isparent < .


// label variables
lab var part "Part"
lab var E "Education"
lab var sex "Gender"
lab def sex 1 "Male" 2 "Female"
lab val sex sex

// create a dichotomous cohort variable 29-44 / 45-58
recode birth (1929/1944 = 1 "1929-44") (1945/1958 = 2 "1945-58"), gen(cohort2)

lab var cohort2 "Cohort"

gen aweight = intb08a7

// condition on valid grandparenthood data (throw away some cases with missing times)
stset durGPH, f(desGPH) id(fallnum) 

keep if _st==1 // 28 obs removed

/*-----------------------------------------
  Save data
-----------------------------------------*/

save "${prepared}/02_Additional_Variables.dta", replace

