/*------------------------------------------------------------------------------
  Skopek & Leopold (2017). 
  Who becomes a Grandparent – And When? Educational Differences in the Chances 
  and Timing of Grandparenthood.
  In: Demographic Research. 
  
  Main analysis as presented in the paper. 
  Generated are: 
	- Tables 1-5 
	- Figures 1-3
------------------------------------------------------------------------------*/

run config


use "${prepared}/02_Additional_Variables.dta", clear

/*-----------------------------------------------------------------------------

TABLE 1 
Descriptive statistics on the total sample, parents, and grandparents 
by part of Germany, gender, and educational level

-----------------------------------------------------------------------------*/

log using "${log}/Table_1.smcl", replace
// 1st PANEL - TOTAL

// case numbers 2,434
count

bys sex: tabstat birth, by(E) stats(mean sd) f(%9.2f)

// West
* date of birth
bys sex: tabstat birth if part==2, by(E) stats(mean sd N min max) f(%9.1f)
* % childless
bys sex: tabstat childless if part==2, by(E) stats(mean sd N) f(%9.3f)
* % grandparents 
bys sex: tabstat desGPH if part==2 , by(E) stats(mean sd N) f(%9.3f)

// East
* date of birth
bys sex: tabstat birth if part==1, by(E) stats(mean sd N min max) f(%9.1f)
* % childless
bys sex: tabstat childless if part==1, by(E) stats(mean sd N ) f(%9.3f)
* % grandparents 
bys sex: tabstat desGPH if part==1 , by(E) stats(mean sd N) f(%9.3f)

// 2nd PANEL - PARENTS 

// case numbers 2,120
count if isparent == 1

// West
* number of biological children
bys sex: tabstat numbiochild if part==2 & isparent==1, by(E) stats(mean sd N) f(%9.1f)
* age at first birth
bys sex: tabstat ttfchild if part==2 & isparent==1, by(E) stats(mean sd N) f(%9.1f)
* % grandparents
bys sex: tabstat desGPH if part==2 & isparent==1, by(E) stats(mean sd N) f(%9.3f)

// East
* number of biological children
bys sex: tabstat numbiochild if part==1 & isparent==1, by(E) stats(mean sd N) f(%9.1f)
* age at first birth
bys sex: tabstat ttfchild if part==1 & isparent==1, by(E) stats(mean sd N) f(%9.1f)
* % grandparents
bys sex: tabstat desGPH if part==1 & isparent==1, by(E) stats(mean sd) f(%9.3f)

// 3rd PANEL - GRANDPARENTS 

// case numbers 1,657
count if desGPH == 1
// West
* number of grandchildren
bys sex: tabstat totgc if part==2 & desGPH==1, by(E) stats(mean sd N) f(%9.1f)
// East
* number of grandchildren
bys sex: tabstat totgc if part==1 & desGPH==1, by(E) stats(mean sd N) f(%9.1f)

log close


/*-------------------------------------------------------------------
 TABLE 2
 Men’s cumulative probability of being father and grandfather 
 at different ages by part of Germany and educational level  
 
 TABLE 3
 Women’s cumulative probability of being mother and grandmother 
 at different ages by part of Germany and educational level 
---------------------------------------------------------------------*/

// create table by the following program
set more off

* over part of germany
foreach part in 1 2 {

	* over sex 
	foreach sex in 1 2 {
		
		* over educational group
		foreach E in 0 1 {
			
			// transition to parenthood
			* define survival time data
			stset ttfchild if part==`part' & sex==`sex' & E==`E', f(isparent) 
			
			* kaplan-meier estimation evaluated at ages 20(5)70; save table
			sts list, fail at(20(5)70) saving("${log}/table_p_part`part'sex`sex'E`E'", replace)
			
			* post-process kaplan-meier table (renvars command needed; type findit renvars) 
			preserve 
				
				use "${log}/table_p_part`part'sex`sex'E`E'", clear
				
				renvars begin-ub, pref(PP`part'S`sex'E`E')
				
				save, replace
				
			restore 
			
			// transition to grandparenthood
			* define survival time data
			stset durGPH if part==`part' & sex==`sex' & E==`E', f(desGPH) 
			
			* kaplan-meier estimation evaluated at ages 40(5)70; save table
			sts list, fail at(40(5)70) saving("${log}/table_gp_part`part'sex`sex'E`E'", replace)
			
			* post-process kaplan-meier table
			preserve 
				
				use "${log}/table_gp_part`part'sex`sex'E`E'", clear
				
				renvars begin-ub, pref(GPP`part'S`sex'E`E')
				
				save, replace
				
			restore 
		}
	}
}

* bring together parts of the table
preserve
	use "${log}/table_p_part1sex1E0", clear
	merge 1:1 time using "${log}/table_p_part1sex1E1", nogen
	merge 1:1 time using "${log}/table_p_part1sex2E0", nogen
	merge 1:1 time using "${log}/table_p_part1sex2E1", nogen
	merge 1:1 time using "${log}/table_p_part2sex1E0", nogen
	merge 1:1 time using "${log}/table_p_part2sex1E1", nogen
	merge 1:1 time using "${log}/table_p_part2sex2E0", nogen
	merge 1:1 time using "${log}/table_p_part2sex2E1", nogen
	
	merge 1:1 time using "${log}/table_gp_part1sex1E0", nogen
	merge 1:1 time using "${log}/table_gp_part1sex1E1", nogen
	merge 1:1 time using "${log}/table_gp_part1sex2E0", nogen
	merge 1:1 time using "${log}/table_gp_part1sex2E1", nogen
	merge 1:1 time using "${log}/table_gp_part2sex1E0", nogen
	merge 1:1 time using "${log}/table_gp_part2sex1E1", nogen
	merge 1:1 time using "${log}/table_gp_part2sex2E0", nogen
	merge 1:1 time using "${log}/table_gp_part2sex2E1", nogen
	
	* over part of Germany 
	foreach part in 1 2 {
	
		* over sex 
		foreach sex in 1 2 {
			
			// Calculate odds ratios 
			
			// Parenthood: odds ratio - low vs. high
			gen ORp_P`part'S`sex' = (PP`part'S`sex'E0failure / (1 - PP`part'S`sex'E0failure) ) ///
						   / (PP`part'S`sex'E1failure / (1 - PP`part'S`sex'E1failure) ) 
						   
			// Grandparenthood: odds ratio - low vs. high
			gen ORgp_P`part'S`sex' = (GPP`part'S`sex'E0failure / (1 - GPP`part'S`sex'E0failure) ) ///
						   / (GPP`part'S`sex'E1failure / (1 - GPP`part'S`sex'E1failure) )  
			
			// Statistical test of oddsratio = 1
			// test of equality of odds, based on the Greenwood standard errors
			// Used is a two-sample z-test for proportions based on the Greenwood approximation for standard errors of the survivor function. 
			
			* Parenthood: low - high
			* z-statistic
			gen zp_P`part'S`sex' = (PP`part'S`sex'E0failure - PP`part'S`sex'E1failure) / sqrt(PP`part'S`sex'E0std_err^2 + PP`part'S`sex'E1std_err^2)
			
			* p-value
			gen pvalp_P`part'S`sex' = 2*(1 - normal(sqrt((zp_P`part'S`sex')^2)))
			
			* add stars
			gen starp_P`part'S`sex' = cond(pvalp_P`part'S`sex'<0.001,"***", ///
											cond(pvalp_P`part'S`sex'<0.01,"**", ///
												 cond(pvalp_P`part'S`sex'<0.05,"*", ///
													  cond(pvalp_P`part'S`sex'<0.1,"+",""))))
			* Grandparenthood: low - high
			* z
			gen zgp_P`part'S`sex' = (GPP`part'S`sex'E0failure - GPP`part'S`sex'E1failure) / sqrt(GPP`part'S`sex'E0std_err^2 + GPP`part'S`sex'E1std_err^2)
			
			* p
			gen pvalgp_P`part'S`sex' = 2*(1 - normal(sqrt((zgp_P`part'S`sex')^2)))
			
			* stars
			gen stargp_P`part'S`sex' = cond(pvalgp_P`part'S`sex'<0.001,"***", ///
											cond(pvalgp_P`part'S`sex'<0.01,"**", ///
												 cond(pvalgp_P`part'S`sex'<0.05,"*", ///
													  cond(pvalgp_P`part'S`sex'<0.1,"+",""))))
													  
													  
		}
	}
	
	// format display
	
	format %9.2f *failure *ub *lb OR* z*
	
	format %9.3f pval*
	
	save "${log}/table", replace
	
restore

// Display columns in Table 2 and 3 (Chi2 square test calculated later)
preserve 
	use "${log}/table", clear
	
	log using "${log}/Table_2.smcl", replace
	// Table 2 - Men, East
	 li time PP1S1E0failure PP1S1E1failure ORp_P1S1 starp_P1S1 ///
			 GPP1S1E0failure GPP1S1E1failure ORgp_P1S1 stargp_P1S1, noobs clean 
    // Table 2 - Men, West
	 li time PP2S1E0failure PP2S1E1failure ORp_P2S1 starp_P2S1 ///
			 GPP2S1E0failure GPP2S1E1failure ORgp_P2S1 stargp_P2S1, noobs clean  		 
	 log close
	
	log using "${log}/Table_3.smcl", replace
	// Table 3 - Women, East		 
	 li time PP1S2E0failure PP1S2E1failure ORp_P1S2 starp_P1S2 ///
			 GPP1S2E0failure GPP1S2E1failure ORgp_P1S2 stargp_P1S2, noobs clean

	// Table 3 - Women, West	
	 li time PP2S2E0failure PP2S2E1failure ORp_P2S2 starp_P2S2 ///
			 GPP2S2E0failure GPP2S2E1failure ORgp_P2S2 stargp_P2S2, noobs clean
	 log close
restore 


/*----------------------------
	Calculate Chi2 values for Table 2 & 3
----------------------------*/


log using "${log}/Table_2_3_chi2.smcl", replace

// Table 2

// Men - East
* parenthood
stset ttfchild if part==1 & sex==1, f(isparent) 

sts list, fail at(20(5)70) by(E)

sts test E, logrank // chi2 0.04


* grandparenthood
stset durGPH if part==1 & sex==1, f(desGPH) 

sts list, fail at(45(5)70) by(E)

sts test E, logrank // chi2: 0.14

// Table 2

// Men - West
* Parenthood
stset ttfchild if part==2 & sex==1, f(isparent) 

sts list, fail at(20(5)70) by(E)

sts test E, logrank // chi2:  4.73

* Grandparenthood
stset durGPH if part==2 & sex==1, f(desGPH) 

sts list, fail at(45(5)70) by(E)

sts test E, logrank // chi2: 17.26

// Table 3 

// Women - East

* parenthood
stset ttfchild if part==1 & sex==2, f(isparent) 

sts list, fail at(20(5)70) by(E)

sts test E, logrank // chi2: 3.16

* grandparenthood
stset durGPH if part==1 & sex==2, f(desGPH) 

sts list, fail at(45(5)70) by(E)

sts test E, logrank // chi2: 4.14

// Table 3
// Women - West
* parenthood 
stset ttfchild if part==2 & sex==2, f(isparent) 

sts list, fail at(20(5)70) by(E) 

sts test E, logrank detail // chi2: 48.58

* grandparenthood
// Unconditional probabilities of being grandparent
stset durGPH if part==2 & sex==2, f(desGPH) 

sts list, fail at(45(5)70) by(E)

sts test E, logrank // chi2: 38.34

log close

/*-------------------------------------------------------------------
	Figure 1 
	Probability of parenthood and grandparenthood by gender, part of Germany, and education. 
	Cumulated probability functions obtained by Kaplan-Meier estimation
-------------------------------------------------------------------*/	

// Transition to Parenthood
stset ttfchild, f(isparent) 

sts list, failure by(part sex E) sav("${log}/parenthood", replace)

// Transition to grandparenthood
stset durGPH , f(desGPH) 

sts list, failure by(part sex E) sav("${log}/grandparenthood", replace)


// combine estimates in one figure

preserve

	use "${log}/parenthood", clear

	gen parenthood = 1

	append using "${log}/grandparenthood"

	egen group = group(part sex E), label

	// East and West combined by sex 
	twoway (line failure time if group== 1 & parenthood == 1 & inrange(time, 15,75), lcol(gs9) lpat(solid) c(l) sort) /// parenthood, east men lower educated
		   (line failure time if group== 2 & parenthood == 1 & inrange(time, 15,75), lcol(gs9) lpat(shortdash) c(l) sort) /// parenthood, east men higher educated
		   (line failure time if group== 1 & parenthood == . & inrange(time, 40,75), c(l) lcol(gs9) lpat(solid) sort) /// grandparenthood, east men lower educated
		   (line failure time if group== 2 & parenthood == . & inrange(time, 40,75), c(l) lcol(gs9) lpat(shortdash) sort) /// grandparenthood, east men higher educated
		   (line failure time if group== 5 & parenthood == 1 & inrange(time, 15,75), lcol(gs0) lpat(solid) c(l) sort) /// parenthood, west men lower educated
		   (line failure time if group== 6 & parenthood == 1 & inrange(time, 15,75), lcol(gs0) lpat(shortdash) c(l) sort) /// parenthood, west men higher educated
		   (line failure time if group== 5 & parenthood == . & inrange(time, 40,75), c(l) lcol(gs0) lpat(solid) sort) /// grandparenthood, west men lower educated
		   (line failure time if group== 6 & parenthood == . & inrange(time, 40,75), c(l) lcol(gs0) lpat(shortdash) sort) /// grandparenthood, west men higher educated
				, ylabel(0 (.1) 1, labsize(small)) scheme(lean1) xlabel(15(5)75, labsize(small)) ///
				legend(lab(3 "Lower educated") /// 
					   lab(4 "Higher educated") /// 
					   size(vsmall) order(3 4) nobox region(color(none)) ring(0) pos(4)) ytitle("Estimated probability", size(small)) ///
					   title("Men", size(medium)) xtitle(Age, size(small)) ///
					   yline(0, lpat(dot) lcol(gs9) lwidth(vthin)) ///
					   yline(.25, lpat(dot) lcol(gs9) lwidth(vthin)) ///
					   yline(.50, lpat(dot) lcol(gs9) lwidth(vthin)) ///
					   yline(.75, lpat(dot) lcol(gs9) lwidth(vthin)) ///
					   yline(1, lpat(dot) lcol(gs9) lwidth(vthin)) /// 
					   text(.7 50 "Grandfatherhood", size(vsmall) col(gs0) justif(right)) ///
					   text(.95 40 "Fatherhood", size(vsmall) col(gs0) justif(right)) ///
					   text(.40 58 "West", size(vsmall) col(gs0) justif(right)) ///
					   text(.45 47 "East", size(vsmall) col(gs9) justif(right)) ///
					   text(.40 30 "West", size(vsmall) col(gs0) justif(right)) ///
					   text(.45 21 "East", size(vsmall) col(gs9) justif(right)) ///
					   xsize(12) ysize(10) ///
					   name(M, replace) 
	// graph export "${log}/Figure_1_MEN.pdf", name(M) replace

	// Women
	twoway (line failure time if group== 3 & parenthood == 1 & inrange(time, 15,75), lcol(gs9) lpat(solid) c(l) sort) /// parenthood, east men lower educated
		   (line failure time if group== 4 & parenthood == 1 & inrange(time, 15,75), lcol(gs9) lpat(shortdash) c(l) sort) /// parenthood, east men higher educated
		   (line failure time if group== 3 & parenthood == . & inrange(time, 35,75), c(l) lcol(gs9) lpat(solid) sort) /// grandparenthood, east men lower educated
		   (line failure time if group== 4 & parenthood == . & inrange(time, 35,75), c(l) lcol(gs9) lpat(shortdash) sort) /// grandparenthood, east men higher educated
		   (line failure time if group== 7 & parenthood == 1 & inrange(time, 15,75), lcol(gs0) lpat(solid) c(l) sort) /// parenthood, east men lower educated
		   (line failure time if group== 8 & parenthood == 1 & inrange(time, 15,75), lcol(gs0) lpat(shortdash) c(l) sort) /// parenthood, east men higher educated
		   (line failure time if group== 7 & parenthood == . & inrange(time, 35,75), c(l) lcol(gs0) lpat(solid) sort) /// grandparenthood, east men lower educated
		   (line failure time if group== 8 & parenthood == . & inrange(time, 35,75), c(l) lcol(gs0) lpat(shortdash) sort) /// grandparenthood, east men higher educated
			, ylabel(0 (.1) 1, labsize(small)) scheme(lean1) xlabel(15(5)75, labsize(small)) ///
				legend(lab(3 "Lower educated") /// 
					   lab(4 "Higher educated") /// 
					   size(vsmall) order(3 4) nobox region(color(none)) ring(0) pos(4)) ytitle("Estimated probability", size(small)) ///
					   title("Women", size(medium)) xtitle(Age, size(small)) ///
					   yline(0, lpat(dot) lcol(gs9) lwidth(vthin)) ///
					   yline(.25, lpat(dot) lcol(gs9) lwidth(vthin)) ///
					   yline(.50, lpat(dot) lcol(gs9) lwidth(vthin)) ///
					   yline(.75, lpat(dot) lcol(gs9) lwidth(vthin)) ///
					   yline(1, lpat(dot) lcol(gs9) lwidth(vthin)) /// 
					   text(.63 44 "Grandmotherhood", size(vsmall) justif(right)) ///
					   text(.95 40 "Motherhood", size(vsmall) col(gs0) justif(right)) ///
					   text(.40 57 "West", size(vsmall) col(gs0) justif(right)) ///
					   text(.45 48 "East", size(vsmall) col(gs9) justif(right)) ///
					   text(.40 25 "West", size(vsmall) col(gs0) justif(right)) ///
					   text(.45 19 "East", size(vsmall) col(gs9) justif(right)) ///
					   xsize(12) ysize(10) ///
					   name(W, replace)
	// graph export "${log}/Figure_1_WOMEN.pdf", name(W) replace

	graph combine M W, row(1) iscale(*1.3) scheme(lean1) xsize(15) ysize(8) imargin(tiny) plotregion(margin(zero)) name(Figure1, replace)
	graph export "${log}/Fig1.pdf", name(Figure1) replace
	graph export "${log}/Fig1.eps", name(Figure1) replace fontface(Helvetica)

restore

/*----------------------------
	FIGURE 2
	Educational differences in median age at grandparenthood. 
	Calculations of median ages and 95% confidence intervals based on Kaplan-Meier estimation for parents 
----------------------------*/

// 1. Calculate median ages manually 

// PARENTHOOD (for comparison)
stset ttfchild if isparent==1, f(isparent) 

* women - east
stci if part==1 & sex==2, by(E)

* women - west
stci if part==2 & sex==2, by(E)

* men - east
stci if part==1 & sex==1, by(E)

* men - west
stci if part==2 & sex==1, by(E)


// GRANDPARENTHOOD
stset durGPH if isparent==1, f(desGPH) 

* women - east
stci if part==1 & sex==2, by(E)

* women - west
stci if part==2 & sex==2, by(E)

* men - east
stci if part==1 & sex==1, by(E)

* men - west
stci if part==2 & sex==1, by(E)



// 2. Generate Figure 

// Store estimates in dataset
egen group = group(part sex E), label

// Parenthood
gen php50 =. 
gen phse = .
gen phlb = .
gen phub = .
gen phGWlb = .
gen phGWub = .

stset ttfchild if isparent==1, f(isparent) 

* store estimates and ci's in variables
foreach num of numlist 1/8 {

	stci if group==`num', by(E)

	foreach item in p50 se lb ub {
	
		replace ph`item' = `r(`item')' if group==`num'
	
	}
	// calculate CI's based on Greenwood standard errors
	replace phGWlb = php50 - invnormal(.975)*phse
	
	replace phGWub = php50 + invnormal(.975)*phse
}

// Grandparenthood
gen gphp50 =. 
gen gphse = .
gen gphlb = .
gen gphub = .
gen gphGWlb = .
gen gphGWub = .

stset durGPH if isparent==1, f(desGPH) 

* store estimates and ci's in variables
foreach num of numlist 1/8 {

	stci if group==`num', by(E)

	foreach item in p50 se lb ub {

		replace gph`item' = `r(`item')' if group==`num'
	
	}
	// calculate CI's based on Greenwood standard errors
	replace gphGWlb = gphp50 - invnormal(.975)*gphse
	
	replace gphGWub = gphp50 + invnormal(.975)*gphse
}



by group, sort: gen first = _n==1 

twoway (rcap gphGWlb gphGWub group if first==1, horizontal msize(vsmall)) ///
	   (rcap phGWlb phGWub group if first==1, horizontal msize(tiny) lcol(gs8)) ///
	   (line group php50 if inlist(group,1,2) & first==1, lpat(shortdash) lwidth(vthin) lcol(none)) ///
	   (line group gphp50 if inlist(group,1,2) & first==1, lpat(shortdash) lwidth(vthin) lcol(none)) ///
	   (line group php50 if inlist(group,3,4) & first==1, lpat(shortdash) lwidth(vthin) lcol(none)) ///
	   (line group gphp50 if inlist(group,3,4) & first==1, lpat(shortdash) lwidth(vthin) lcol(none)) ///
	   (line group php50 if inlist(group,5,6) & first==1, lpat(shortdash) lwidth(vthin) lcol(none)) ///
	   (line group gphp50 if inlist(group,5,6) & first==1, lpat(shortdash) lwidth(vthin) lcol(none)) ///
	   (line group php50 if inlist(group,7,8) & first==1, lpat(shortdash) lwidth(vthin) lcol(none)) ///
	   (line group gphp50 if inlist(group,7,8) & first==1, lpat(shortdash) lwidth(vthin) lcol(none)) ///
	   (scatter group gphp50 if first==1 & mod(group,2)!=0, msymb(D) mfcol(white) mlab(gphp50) mlabpos(6) mlabsize(vsmall) ) ///
	   (scatter group gphp50 if first==1 & mod(group,2)==0, msymb(D) mfcol(white) mlab(gphp50) mlabpos(12) mlabsize(vsmall)) ///
	   (scatter group php50 if first==1 & mod(group,2)!=0, msymb(T) mfcol(white) mlcol(gs8) mlab(php50) mlabpos(6) mlabsize(vsmall) mlabcol(gs8)) ///
	   (scatter group php50 if first==1 & mod(group,2)==0, msymb(T) mfcol(white) mlcol(gs8) mlab(php50) mlabpos(12) mlabsize(vsmall) mlabcol(gs8)) ///
	   , xlabel(15(5)65, labsize(small) ) ///
	   scheme(lean1) yscale(range(.5 8.5)) ytitle("") /// 
	   legend(lab(11 "First grandchild") lab(13 "First child") size(small) order(13 11) row(1) pos(6)) ///
	   xtitle("Median age", size(small))  ///
	   ytitle(" ", margin(medium)) ///
	   ylabel(1 "Lower" ///
			  2 "Higher" ///
			  3 "Lower" ///
			  4 "Higher" ///
			  5 "Lower" ///
			  6 "Higher" ///
			  7 "Lower" ///
			  8 "Higher" ///
			  , grid glcol(gs10) labsize(vsmall)  angle(360)) ///
	   text(6.5 6.5 "West", justif(left)) text(2.5 6.5 "East", justif(left)) ///
	   text(7.5 10 "Women", size(small) justif(right)) text(5.5 10 "Men", size(small) justif(right)) ///
	   text(3.5 10 "Women", size(small) justif(right)) text(1.5 10 "Men", size(small) justif(right)) ///
	   name(timing, replace)
	   
graph export "${log}/Fig2.pdf", name(timing) replace
graph export "${log}/Fig2.eps", name(timing) replace fontface(Helvetica)






