/*------------------------------------------------------------------------------
  Skopek & Leopold (2017). 
  Who becomes a Grandparent – And When? Educational Differences in the Chances 
  and Timing of Grandparenthood.
  In: Demographic Research. 
  
  Additional analyses (not shown in the paper)
  
  I) Accounting for potential survivor bias via re-weighting
	-> replicates all analyses using weights that account for 
	   potential samples seletion bias resulting from potential 
	   fertility effects on mortatily. 
	   
  II) Additional analyses on higher parity grandparenthood 
  
  III) Additional analyses on higher parity parenthood 
  
------------------------------------------------------------------------------*/

run config


use "${prepared}/02_Additional_Variables.dta", clear


/*-------------------------------------------------------------------
  I) Accounting for potential survivor bias
-------------------------------------------------------------------*/

/*

We selected persons aged 60-75 at time of interview (2008). Due to differential 
mortality, this is not a perfectly representative sample of persons born 1933-1948. 

First, higher education is associated with longevity (e.g., Dolbhammer 2000). 
This would only affect the marginal distribution of education in our sample. 
Since our analysis is stratified by education, this is not a severe issue for our findings. 

Second, mortality may differ by fertility history. The literature suggests that childless women and higher-parity women have a slightly higher mortality risk compared to women in typical parity (2-3 children) (e.g., Lund et al. 1990 for Norway). However, meta analyses (Hurt et al. 2006) report inconsistent associations between women’s number of births and mortality with typically very small effect sizes. For contemporary populations either no effect or slightly elevated mortality for women with large number of children was reported. Findings for Austria (which is closest to the German case) suggest that the influence of reproductive history on longevity is small compared to differences in longevity stemming from environmental factors such as level of education or family status (Doblhammer 2000). 

Hence, while survivor bias may affect marginal distributions of education, it is unlikely to substantially distort our findings on the transition to parenthood and grandparenthood within educational groups.   

However, to challenge these assumptions we did additional robustness checks by adjusting for potential survivor bias due to mortality differentials by family history using parameters found for the Austrian case as reported by Dolbhammer (2000).
 
Conditional on other factors, relative mortality risks (in terms of odds ratios) for women aged 50+ were (see Dolbhammer 2000, p. 171, Table 1)

0 births	1.15
1 birth		1.01
2 births	1.00 (ref)
3 births	1.02
4 births	1.06
5+ births	1.10

Using these odds ratios, we re-weighted the data in order to counteract potential selection bias. Consequently, childless persons and child-rich persons receive a higher relative weight compared to persons with 2 children. 

Note that the association between fertility and mortality in men is much lower than in women. Hence, by assigning the same weights to men, we are overly conservative here.  

We re-calculated our main results in Tables 2 & 3 and Figures 1 & 2 applying the weighting. Note that using the weights, standard errors could not be calculated. Hence, we compared point estimates to assess the robustness of our main findings. As the following material will show, estimates obtained from the weighted analyses were very close to the unweighted estimates. If at all, educational differences in parent- and grandparenthood seem to be even more pronounced when taking into account potential selectivity by the reweighting. None of our results changed substantially. 


References: 
Lund, E., Arnesen, E., & Borgan, J. K. (1990). Pattern of childbearing and mortality 
in married women-a national prospective study from Norway. 
Journal of Epidemiology and Community Health, 44(3), 237–240. 
http://doi.org/10.1136/jech.44.3.237 

Hurt, L. S., Ronsmans, C., & Thomas, S. L. (2006). The effect of number of births 
on women’s mortality: Systematic review of the evidence for women who have 
completed their childbearing. Population Studies, 60(1), 55–71. 
http://doi.org/10.1080/00324720500436011

Doblhammer, G. (2000). Reproductive history and mortality later in life: 
a comparative study of England and Wales and Austria. Population Studies, 54(2), 
169–176. http://doi.org/10.1080/713779087

*/

// Create the weight according to OR parameters from Dolbhammer (2000)
gen sor = 1/1.15 if numbiochild == 0

replace sor = 1/1.01 if numbiochild == 1

replace sor = 1/1.00 if numbiochild == 2

replace sor = 1/1.02 if numbiochild == 3

replace sor = 1/1.06 if numbiochild == 4

replace sor = 1/1.10 if numbiochild >= 5 & numbiochild < .

gen isor = 1/sor

tabstat isor, by(numbiochild)

histogram isor

/*-------------------------------------------------------------------
	Reproduce Figure 1 using the inverse odds ratio weighting 
	
	-> estimates substantially very similar! 
	
	Figure 1 
	Probability of parenthood and grandparenthood by gender, part of Germany, and education. 
	Cumulated probability functions obtained by Kaplan-Meier estimation
-------------------------------------------------------------------*/	

// Transition to Parenthood -> define weight! 
stset ttfchild [pw=isor], f(isparent) 

sts list, failure by(part sex E) sav("${log}/parenthood_isor", replace)

// Transition to grandparenthood -> define weight! 
stset durGPH [pw=isor], f(desGPH) 

sts list, failure by(part sex E) sav("${log}/grandparenthood_isor", replace)


// combine estimates in one figure

preserve

	use "${log}/parenthood_isor", clear

	gen parenthood = 1

	append using "${log}/grandparenthood_isor"

	egen group = group(part sex E), label

	// East and West combined by sex 
	twoway (line failure time if group== 1 & parenthood == 1 & inrange(time, 15,75), lcol(gs9) lpat(solid) c(l) sort) /// parenthood, east men lower educated
		   (line failure time if group== 2 & parenthood == 1 & inrange(time, 15,75), lcol(gs9) lpat(shortdash) c(l) sort) /// parenthood, east men higher educated
		   (line failure time if group== 1 & parenthood == . & inrange(time, 40,75), c(l) lcol(gs9) lpat(solid) sort) /// grandparenthood, east men lower educated
		   (line failure time if group== 2 & parenthood == . & inrange(time, 40,75), c(l) lcol(gs9) lpat(shortdash) sort) /// grandparenthood, east men higher educated
		   (line failure time if group== 5 & parenthood == 1 & inrange(time, 15,75), lcol(gs0) lpat(solid) c(l) sort) /// parenthood, west men lower educated
		   (line failure time if group== 6 & parenthood == 1 & inrange(time, 15,75), lcol(gs0) lpat(shortdash) c(l) sort) /// parenthood, west men higher educated
		   (line failure time if group== 5 & parenthood == . & inrange(time, 40,75), c(l) lcol(gs0) lpat(solid) sort) /// grandparenthood, west men lower educated
		   (line failure time if group== 6 & parenthood == . & inrange(time, 40,75), c(l) lcol(gs0) lpat(shortdash) sort) /// grandparenthood, west men higher educated
				, ylabel(0 (.1) 1, labsize(small)) scheme(lean1) xlabel(15(5)75, labsize(small)) ///
				legend(lab(3 "Lower educated") /// 
					   lab(4 "Higher educated") /// 
					   size(vsmall) order(3 4) nobox region(color(none)) ring(0) pos(4)) ytitle("Estimated probability", size(small)) ///
					   title("Men", size(medium)) xtitle(Age, size(small)) ///
					   yline(0, lpat(dot) lcol(gs9) lwidth(vthin)) ///
					   yline(.25, lpat(dot) lcol(gs9) lwidth(vthin)) ///
					   yline(.50, lpat(dot) lcol(gs9) lwidth(vthin)) ///
					   yline(.75, lpat(dot) lcol(gs9) lwidth(vthin)) ///
					   yline(1, lpat(dot) lcol(gs9) lwidth(vthin)) /// 
					   text(.7 50 "Grandfatherhood", size(vsmall) col(gs0) justif(right)) ///
					   text(.95 40 "Fatherhood", size(vsmall) col(gs0) justif(right)) ///
					   text(.40 58 "West", size(vsmall) col(gs0) justif(right)) ///
					   text(.45 47 "East", size(vsmall) col(gs9) justif(right)) ///
					   text(.40 30 "West", size(vsmall) col(gs0) justif(right)) ///
					   text(.45 21 "East", size(vsmall) col(gs9) justif(right)) ///
					   xsize(12) ysize(10) ///
					   name(M, replace) 
	// graph export "${log}/Figure_1_MEN.pdf", name(M) replace

	// Women
	twoway (line failure time if group== 3 & parenthood == 1 & inrange(time, 15,75), lcol(gs9) lpat(solid) c(l) sort) /// parenthood, east men lower educated
		   (line failure time if group== 4 & parenthood == 1 & inrange(time, 15,75), lcol(gs9) lpat(shortdash) c(l) sort) /// parenthood, east men higher educated
		   (line failure time if group== 3 & parenthood == . & inrange(time, 35,75), c(l) lcol(gs9) lpat(solid) sort) /// grandparenthood, east men lower educated
		   (line failure time if group== 4 & parenthood == . & inrange(time, 35,75), c(l) lcol(gs9) lpat(shortdash) sort) /// grandparenthood, east men higher educated
		   (line failure time if group== 7 & parenthood == 1 & inrange(time, 15,75), lcol(gs0) lpat(solid) c(l) sort) /// parenthood, east men lower educated
		   (line failure time if group== 8 & parenthood == 1 & inrange(time, 15,75), lcol(gs0) lpat(shortdash) c(l) sort) /// parenthood, east men higher educated
		   (line failure time if group== 7 & parenthood == . & inrange(time, 35,75), c(l) lcol(gs0) lpat(solid) sort) /// grandparenthood, east men lower educated
		   (line failure time if group== 8 & parenthood == . & inrange(time, 35,75), c(l) lcol(gs0) lpat(shortdash) sort) /// grandparenthood, east men higher educated
			, ylabel(0 (.1) 1, labsize(small)) scheme(lean1) xlabel(15(5)75, labsize(small)) ///
				legend(lab(3 "Lower educated") /// 
					   lab(4 "Higher educated") /// 
					   size(vsmall) order(3 4) nobox region(color(none)) ring(0) pos(4)) ytitle("Estimated probability", size(small)) ///
					   title("Women", size(medium)) xtitle(Age, size(small)) ///
					   yline(0, lpat(dot) lcol(gs9) lwidth(vthin)) ///
					   yline(.25, lpat(dot) lcol(gs9) lwidth(vthin)) ///
					   yline(.50, lpat(dot) lcol(gs9) lwidth(vthin)) ///
					   yline(.75, lpat(dot) lcol(gs9) lwidth(vthin)) ///
					   yline(1, lpat(dot) lcol(gs9) lwidth(vthin)) /// 
					   text(.63 44 "Grandmotherhood", size(vsmall) justif(right)) ///
					   text(.95 40 "Motherhood", size(vsmall) col(gs0) justif(right)) ///
					   text(.40 57 "West", size(vsmall) col(gs0) justif(right)) ///
					   text(.45 48 "East", size(vsmall) col(gs9) justif(right)) ///
					   text(.40 25 "West", size(vsmall) col(gs0) justif(right)) ///
					   text(.45 19 "East", size(vsmall) col(gs9) justif(right)) ///
					   xsize(12) ysize(10) ///
					   name(W, replace)

	graph combine M W, row(1) iscale(*1.3) scheme(lean1) xsize(15) ysize(8) imargin(tiny) plotregion(margin(zero)) name(Figure1, replace)
	graph export "${log}/Fig1_isor.pdf", name(Figure1) replace

restore


/*-------------------------------------------------------------------
 Reproduce estimates for Table 2 and 3 using the weights 
 (note that standard errors cannot be estimated by stata)
 
 The estimates were substantially very similar. 
 
 TABLE 2
 Men’s cumulative probability of being father and grandfather 
 at different ages by part of Germany and educational level  
 
 TABLE 3
 Women’s cumulative probability of being mother and grandmother 
 at different ages by part of Germany and educational level 
---------------------------------------------------------------------*/

/*
stset ttfchild if part==2 & sex==2 & E==0 , f(isparent) 
sts list, fail at(20(5)70) saving("${log}/table_isor_p_part`part'sex`sex'E`E'", replace)

sts list, fail at(20(5)70)
*/
// create table by the following program
set more off

* over part of germany
foreach part in 1 2 {

	* over sex 
	foreach sex in 1 2 {
		
		* over educational group
		foreach E in 0 1 {
			
			// transition to parenthood
			* define survival time data
			stset ttfchild if part==`part' & sex==`sex' & E==`E' [pw=isor], f(isparent) 
			
			* kaplan-meier estimation evaluated at ages 20(5)70; save table
			sts list, fail at(20(5)70) saving("${log}/table_isor_p_part`part'sex`sex'E`E'", replace)
			
			* post-process kaplan-meier table (renvars command needed; type findit renvars) 
			preserve 
				
				use "${log}/table_isor_p_part`part'sex`sex'E`E'", clear
				
				renvars begin-failure, pref(PP`part'S`sex'E`E')
				
				save, replace
				
			restore 
			
			// transition to grandparenthood
			* define survival time data
			stset durGPH if part==`part' & sex==`sex' & E==`E' [pw=isor], f(desGPH) 
			
			* kaplan-meier estimation evaluated at ages 40(5)70; save table
			sts list, fail at(40(5)70) saving("${log}/table_isor_gp_part`part'sex`sex'E`E'", replace)
			
			* post-process kaplan-meier table
			preserve 
				
				use "${log}/table_isor_gp_part`part'sex`sex'E`E'", clear
				
				renvars begin-failure, pref(GPP`part'S`sex'E`E')
				
				save, replace
				
			restore 
		}
	}
}

* bring together parts of the table
preserve
	use "${log}/table_isor_p_part1sex1E0", clear
	merge 1:1 time using "${log}/table_isor_p_part1sex1E1", nogen
	merge 1:1 time using "${log}/table_isor_p_part1sex2E0", nogen
	merge 1:1 time using "${log}/table_isor_p_part1sex2E1", nogen
	merge 1:1 time using "${log}/table_isor_p_part2sex1E0", nogen
	merge 1:1 time using "${log}/table_isor_p_part2sex1E1", nogen
	merge 1:1 time using "${log}/table_isor_p_part2sex2E0", nogen
	merge 1:1 time using "${log}/table_isor_p_part2sex2E1", nogen
	
	merge 1:1 time using "${log}/table_isor_gp_part1sex1E0", nogen
	merge 1:1 time using "${log}/table_isor_gp_part1sex1E1", nogen
	merge 1:1 time using "${log}/table_isor_gp_part1sex2E0", nogen
	merge 1:1 time using "${log}/table_isor_gp_part1sex2E1", nogen
	merge 1:1 time using "${log}/table_isor_gp_part2sex1E0", nogen
	merge 1:1 time using "${log}/table_isor_gp_part2sex1E1", nogen
	merge 1:1 time using "${log}/table_isor_gp_part2sex2E0", nogen
	merge 1:1 time using "${log}/table_isor_gp_part2sex2E1", nogen
	
	* over part of Germany 
	foreach part in 1 2 {
	
		* over sex 
		foreach sex in 1 2 {
			
			// Calculate odds ratios 
			
			// Parenthood: odds ratio - low vs. high
			gen ORp_P`part'S`sex' = (PP`part'S`sex'E0failure / (1 - PP`part'S`sex'E0failure) ) ///
						   / (PP`part'S`sex'E1failure / (1 - PP`part'S`sex'E1failure) ) 
						   
			// Grandparenthood: odds ratio - low vs. high
			gen ORgp_P`part'S`sex' = (GPP`part'S`sex'E0failure / (1 - GPP`part'S`sex'E0failure) ) ///
						   / (GPP`part'S`sex'E1failure / (1 - GPP`part'S`sex'E1failure) )  
			
													  
													  
		}
	}
	
	// format display
	
	format %9.2f *failure OR* 

	
	save "${log}/table_isor", replace
	
restore

// Display columns in Table 2 and 3 
preserve 
	use "${log}/table_isor", clear
	
	log using "${log}/Table_2_isor.smcl", replace
	// Table 2 - Men, East
	 li time PP1S1E0failure PP1S1E1failure ORp_P1S1  ///
			 GPP1S1E0failure GPP1S1E1failure ORgp_P1S1 , noobs clean 
    // Table 2 - Men, West
	 li time PP2S1E0failure PP2S1E1failure ORp_P2S1  ///
			 GPP2S1E0failure GPP2S1E1failure ORgp_P2S1 , noobs clean  		 
	 log close
	
	log using "${log}/Table_3_isor.smcl", replace
	// Table 3 - Women, East		 
	 li time PP1S2E0failure PP1S2E1failure ORp_P1S2  ///
			 GPP1S2E0failure GPP1S2E1failure ORgp_P1S2 , noobs clean

	// Table 3 - Women, West	
	 li time PP2S2E0failure PP2S2E1failure ORp_P2S2  ///
			 GPP2S2E0failure GPP2S2E1failure ORgp_P2S2 , noobs clean
	 log close
restore 


/*----------------------------
	
	Reproduce Figure 2 using inverse odds ratio weights
	
	FIGURE 2
	Educational differences in median age at grandparenthood. 
	Calculations of median ages and 95% confidence intervals based on Kaplan-Meier estimation for parents 
----------------------------*/

// 1. Calculate median ages manually 

// 2. Generate Figure 

// Store estimates in dataset
egen group = group(part sex E), label

// Parenthood
gen php50 =. 


stset ttfchild if isparent==1 [pw=isor], f(isparent) 

* store estimates and ci's in variables
foreach num of numlist 1/8 {
	
	// note: stci does not work with weights, use stsum instead
	// stci if group==`num', by(E)

	stsum if group == `num' 

	replace php50 = r(p50) if group==`num'
}

// Grandparenthood
gen gphp50 =. 

stset durGPH if isparent==1 [pw=isor], f(desGPH) 

* store estimates and ci's in variables
foreach num of numlist 1/8 {

	stsum if group == `num' 
	
	replace gphp50 = r(p50) if group==`num'
}



by group, sort: gen first = _n==1 

twoway (line group php50 if inlist(group,1,2) & first==1, lpat(shortdash) lwidth(vthin) lcol(none)) ///
	   (line group gphp50 if inlist(group,1,2) & first==1, lpat(shortdash) lwidth(vthin) lcol(none)) ///
	   (line group php50 if inlist(group,3,4) & first==1, lpat(shortdash) lwidth(vthin) lcol(none)) ///
	   (line group gphp50 if inlist(group,3,4) & first==1, lpat(shortdash) lwidth(vthin) lcol(none)) ///
	   (line group php50 if inlist(group,5,6) & first==1, lpat(shortdash) lwidth(vthin) lcol(none)) ///
	   (line group gphp50 if inlist(group,5,6) & first==1, lpat(shortdash) lwidth(vthin) lcol(none)) ///
	   (line group php50 if inlist(group,7,8) & first==1, lpat(shortdash) lwidth(vthin) lcol(none)) ///
	   (line group gphp50 if inlist(group,7,8) & first==1, lpat(shortdash) lwidth(vthin) lcol(none)) ///
	   (scatter group gphp50 if first==1 & mod(group,2)!=0, msymb(D) mfcol(white) mlab(gphp50) mlabpos(6) mlabsize(vsmall) ) ///
	   (scatter group gphp50 if first==1 & mod(group,2)==0, msymb(D) mfcol(white) mlab(gphp50) mlabpos(12) mlabsize(vsmall)) ///
	   (scatter group php50 if first==1 & mod(group,2)!=0, msymb(T) mfcol(white) mlcol(gs8) mlab(php50) mlabpos(6) mlabsize(vsmall) mlabcol(gs8)) ///
	   (scatter group php50 if first==1 & mod(group,2)==0, msymb(T) mfcol(white) mlcol(gs8) mlab(php50) mlabpos(12) mlabsize(vsmall) mlabcol(gs8)) ///
	   , xlabel(15(5)65, labsize(small) ) ///
	   scheme(lean1) yscale(range(.5 8.5)) ytitle("") /// 
	   legend(lab(9 "First grandchild") lab(11 "First child") size(small) order(11 9) row(1) pos(6)) ///
	   xtitle("Median age", size(small))  ///
	   ytitle(" ", margin(medium)) ///
	   ylabel(1 "Lower" ///
			  2 "Higher" ///
			  3 "Lower" ///
			  4 "Higher" ///
			  5 "Lower" ///
			  6 "Higher" ///
			  7 "Lower" ///
			  8 "Higher" ///
			  , grid glcol(gs10) labsize(vsmall)  angle(360)) ///
	   text(6.5 6.5 "West", justif(left)) text(2.5 6.5 "East", justif(left)) ///
	   text(7.5 10 "Women", size(small) justif(right)) text(5.5 10 "Men", size(small) justif(right)) ///
	   text(3.5 10 "Women", size(small) justif(right)) text(1.5 10 "Men", size(small) justif(right)) ///
	   name(timing, replace)
	   
graph export "${log}/Fig2_isor.pdf", name(timing) replace


/*-------------------------------------------------------------------
 II) Higher parity grandparenthood 
 TABLE 4
 Probability of having a second and third grandchild conditional on 
 lower parities by gender, part of Germany and educational level
---------------------------------------------------------------------*/

// create table by the following program
set more off
foreach part in 1 2 {
	foreach sex in 1 2 {
		foreach E in 0 1 {
			// grandparenthood - parity 1 (time since first birth)
			stset durGPH if isparent==1 & ///
							part==`part' & sex==`sex' & E==`E' ///
							, f(desGPH) origin(time ttfchild)

			sts list, fail at(2(2)12) saving("${log}/table4_PARITY-1_part`part'sex`sex'E`E'", replace)
			stdes 
			preserve 
				use "${log}/table4_PARITY-1_part`part'sex`sex'E`E'", clear
				gen N=`r(N_sub)'
				gen e=`r(N_fail)'
				renvars begin-e, pref(Par1P`part'S`sex'E`E')
				save, replace
			restore 
			
			// grandparenthood - parity 2 (time since first grandchild)
			stset durGPHnr2 if desGPH ==1 & ///
							part==`part' & sex==`sex' & E==`E' ///
							, f(desGPHnr2) // there are some cases with missing values (excluded)

			sts list, fail at(2(2)12) saving("${log}/table4_PARITY-2_part`part'sex`sex'E`E'", replace)
			stdes
			preserve 
				use "${log}/table4_PARITY-2_part`part'sex`sex'E`E'", clear
				gen N=`r(N_sub)'
				gen e=`r(N_fail)'
				renvars begin-e, pref(Par2P`part'S`sex'E`E')
				save, replace
			restore 
			
			// grandparenthood - parity 3 (time since second grandchild)
			stset durGPHnr3 if desGPHnr2 ==1 & ///
							part==`part' & sex==`sex' & E==`E' ///
							, f(desGPHnr3) // there are some cases with missing values (excluded)

			sts list, fail at(2(2)12) saving("${log}/table4_PARITY-3_part`part'sex`sex'E`E'", replace)
			stdes
			preserve 
				use "${log}/table4_PARITY-3_part`part'sex`sex'E`E'", clear
				gen N=`r(N_sub)'
				gen e=`r(N_fail)'
				renvars begin-e, pref(Par3P`part'S`sex'E`E')
				save, replace
			restore 
			
		}
		
		// chi2 values
		// parity 1 
		stset durGPH if isparent==1 & ///
							part==`part' & sex==`sex'  ///
							, f(desGPH) origin(time ttfchild)
		sts test E, logrank 
		preserve
			gen Chi2_Par1P`part'S`sex' = `r(chi2)'
			gen Chi2pval_Par1P`part'S`sex' =  1 - chi2(`r(df)', `r(chi2)')
			keep Chi2*
			keep in 1
			save "${log}/table4_chi2_PARITY-1_part`part'sex`sex'", replace
		restore
		
		// parity 2
		stset durGPHnr2 if desGPH ==1 & ///
							part==`part' & sex==`sex'  ///
							, f(desGPHnr2) // there are some cases with missing values (excluded)
		sts test E, logrank 
		preserve
			gen Chi2_Par2P`part'S`sex' = `r(chi2)'
			gen Chi2pval_Par2P`part'S`sex' =  1 - chi2(`r(df)', `r(chi2)')
			keep Chi2*
			keep in 1
			save "${log}/table4_chi2_PARITY-2_part`part'sex`sex'", replace
		restore
		
		// parity 3
		stset durGPHnr3 if desGPHnr2 ==1 & ///
							part==`part' & sex==`sex'  ///
							, f(desGPHnr3) // there are some cases with missing values (excluded)
		sts test E, logrank 
		preserve
			gen Chi2_Par3P`part'S`sex' = `r(chi2)'
			gen Chi2pval_Par3P`part'S`sex' =  1 - chi2(`r(df)', `r(chi2)')
			keep Chi2*
			keep in 1
			save "${log}/table4_chi2_PARITY-3_part`part'sex`sex'", replace
		restore

	}
}
preserve
	
foreach parity in 1 2 3 {
	foreach part in 1 2 {
	foreach sex in 1 2 {
		foreach E in 0 1 {
			if `parity' == 1 & `part'==1 & `sex'==1 & `E'==0 {
				use "${log}/table4_PARITY-`parity'_part`part'sex`sex'E`E'", clear
			} 
			else {
				merge 1:1 time using "${log}/table4_PARITY-`parity'_part`part'sex`sex'E`E'", nogen
			}
			
		}
		
	}
}
}


		
foreach parity in 1 2 3 {
	foreach part in 1 2 {
		foreach sex in 1 2 {
			// Parenthood: odds ratio - low vs. high
			gen OR_Par`parity'P`part'S`sex' = (Par`parity'P`part'S`sex'E0failure / (1 - Par`parity'P`part'S`sex'E0failure) ) ///
						   / (Par`parity'P`part'S`sex'E1failure / (1 - Par`parity'P`part'S`sex'E1failure) )  
			// Used is a two-sample z-test for proportions based on the Greenwood approximation for standard errors of the survivor function. 
			// low - high
			gen z_Par`parity'P`part'S`sex' = (Par`parity'P`part'S`sex'E0failure - Par`parity'P`part'S`sex'E1failure) / sqrt(Par`parity'P`part'S`sex'E0std_err^2 + Par`parity'P`part'S`sex'E1std_err^2)
			gen pval_Par`parity'P`part'S`sex' = 2*(1 - normal(sqrt((z_Par`parity'P`part'S`sex')^2)))
			gen star_Par`parity'P`part'S`sex' = cond(pval_Par`parity'P`part'S`sex'<0.001,"***", ///
											cond(pval_Par`parity'P`part'S`sex'<0.01,"**", ///
												 cond(pval_Par`parity'P`part'S`sex'<0.05,"*", ///
													  cond(pval_Par`parity'P`part'S`sex'<0.1,"+",""))))
													  
			merge 1:1 _n using "${log}/table4_chi2_PARITY-`parity'_part`part'sex`sex'", nogen
													  
													  
		}
	}
}
	format %9.2f *failure *ub *lb OR* z*
	format %9.3f pval*
	
	save "${log}/table4", replace
	
restore

// display table components
preserve 
	use "${log}/table4", clear
	format %9.3f Chi2pval_*
	format %9.2f Chi2_*
	log using "${log}/Table_4.smcl", replace
	// display  East Germany, Men - second and third parity
	li time Par2P1S1E0failure Par2P1S1E1failure OR_Par2P1S1 star_Par2P1S1 ///
			 Par3P1S1E0failure Par3P1S1E1failure OR_Par3P1S1 star_Par3P1S1 , noobs clean
	// li case numbers and chi2 
	li  Par2P1S1E0N Par2P1S1E0e Chi2_Par2P1S1 Par2P1S1E1N Par2P1S1E1e Chi2_Par2P1S1 ///
		Par3P1S1E0N Par3P1S1E0e Chi2_Par3P1S1 Par3P1S1E1N Par3P1S1E1e Chi2_Par3P1S1 ///
			 in 1, noobs clean
	
	// display  East Germany, Women - second and third parity
	li time Par2P1S2E0failure Par2P1S2E1failure OR_Par2P1S2 star_Par2P1S2 ///
			Par3P1S2E0failure Par3P1S2E1failure OR_Par3P1S2 star_Par3P1S2, noobs clean
	// li case numbers and chi2 
	li  Par2P1S2E0N Par2P1S2E0e Chi2_Par2P1S2 Par2P1S2E1N Par2P1S2E1e Chi2_Par2P1S2 ///
		Par3P1S2E0N Par3P1S2E0e Chi2_Par3P1S2 Par3P1S2E1N Par3P1S2E1e Chi2_Par3P1S2 ///
			 in 1, noobs clean
	
	// display  West Germany, Men - second and third parity
	li time Par2P2S1E0failure Par2P2S1E1failure OR_Par2P2S1 star_Par2P2S1 ///
			Par3P2S1E0failure Par3P2S1E1failure OR_Par3P2S1 star_Par3P2S1, noobs clean
	// li case numbers and chi2 
	li  Par2P2S1E0N Par2P2S1E0e Chi2_Par2P2S1 Par2P2S1E1N Par2P2S1E1e Chi2_Par2P2S1 ///
		Par3P2S1E0N Par3P2S1E0e Chi2_Par3P2S1 Par3P2S1E1N Par3P2S1E1e Chi2_Par3P2S1 ///
			 in 1, noobs clean
			 
	// display  West Germany, Women - second and third parity
	li time Par2P2S2E0failure Par2P2S2E1failure OR_Par2P2S2 star_Par2P2S2 ///
			Par3P2S2E0failure Par3P2S2E1failure OR_Par3P2S2 star_Par3P2S2, noobs clean
	// li case numbers and chi2 
	li  Par2P2S2E0N Par2P2S2E0e Chi2_Par2P2S2 Par2P2S2E1N Par2P2S2E1e Chi2_Par2P2S2 ///
		Par3P2S2E0N Par3P2S2E0e Chi2_Par3P2S2 Par3P2S2E1N Par3P2S2E1e Chi2_Par3P2S2 ///
			 in 1, noobs clean
	log close
restore 

/*----------------------------
	Calculate Chi2 values 
----------------------------*/



// Men - East

// Additional analyses (not reported in the paper) >>>>>
// Grandparenthood Parities: 

// Conditional probabilities of being grandparent (conditional on being parent)
stset durGPH if part==1 & sex==1 & isparent==1, f(desGPH) 
sts list, fail at(45(5)70) by(E)
sts test E, logrank
stci, by(E)

// time since first birth
stset durGPH if isparent==1 & part==1 & sex==1, f(desGPH) origin(time ttfchild)
sts list, fail at(20(5)45) by(E)
sts test E, logrank

// time since first grandchild
stset durGPHnr2 if desGPH ==1 & part==1 & sex==1, f(desGPHnr2)
sts list, fail at(0(2)10) by(E)

// time since second grandchild 
stset durGPHnr3 if desGPHnr2 ==1 & part==1 & sex==1, f(desGPHnr3)
sts list, fail at(0(2)10) by(E)
// <<<<< additional analyses end

// Men - West
// Additional analyses (not reported in the paper) >>>>>
// Grandparenthood Parities: 

// Conditional probabilities of being grandparent (conditional on being parent)
stset durGPH if part==2 & sex==1 & isparent==1, f(desGPH) 
sts list, fail at(45(5)70) by(E)
sts test E, logrank
stci, by(E)

// time since first birth
stset durGPH if isparent==1 & part==2 & sex==1, f(desGPH) origin(time ttfchild)
sts list, fail at(20(5)45) by(E)

// time since first grandchild
stset durGPHnr2 if desGPH ==1 & part==2 & sex==1, f(desGPHnr2)
sts list, fail at(0(2)10) by(E)

// time since second grandchild 
stset durGPHnr3 if desGPHnr2 ==1 & part==2 & sex==1, f(desGPHnr3)
sts list, fail at(0(2)10) by(E)
// <<<<< additional analyses end



// Women - East
// Additional analyses (not reported in the paper) >>>>>
// Grandparenthood Parities: 

// Conditional probabilities of being grandparent (conditional on being parent)
stset durGPH if part==1 & sex==2 & isparent==1, f(desGPH) 
sts list, fail at(45(5)70) by(E)
sts test E, logrank
stci, by(E)

// time since first birth
stset durGPH if isparent==1 & part==1 & sex==2, f(desGPH) origin(time ttfchild)
sts list, fail at(20(5)45) by(E)

// time since first grandchild
stset durGPHnr2 if desGPH ==1 & part==1 & sex==2, f(desGPHnr2)
sts list, fail at(0(2)10) by(E)

// time since second grandchild (to few cases for women)
stset durGPHnr3 if desGPHnr2 ==1 & part==1 & sex==2, f(desGPHnr3)
sts list, fail at(0(2)10) by(E)
// <<<<< additional analyses end

// Women - West
// Additional analyses (not reported in the paper) >>>>>
// Grandparenthood Parities: 

// Conditional probabilities of being grandparent (conditional on being parent)
stset durGPH if part==2 & sex==2 & isparent==1, f(desGPH) 
sts list, fail at(45(5)70) by(E)
sts test E, logrank
stci, by(E)

// time since first birth
stset durGPH if isparent==1 & part==2 & sex==2, f(desGPH) origin(time ttfchild)
sts list, fail at(20(5)45) by(E)

// time since first grandchild
stset durGPHnr2 if desGPH ==1 & part==2 & sex==2, f(desGPHnr2)
sts list, fail at(0(2)10) by(E)

// time since second grandchild (to few cases for women)
stset durGPHnr3 if desGPHnr2 ==1 & part==2 & sex==2, f(desGPHnr3)
sts list, fail at(0(2)10) by(E)
// <<<<< additional analyses end

/*-------------------------------------------------------------------
 TABLE 5
 Median time to parity level (in years) by gender, 
 part of Germany, and educational level 
---------------------------------------------------------------------*/

gen GPp50_PSE_Par1 = .
gen GPp50_PS_Par1 = .

gen GPp50_PSE_Par2 = .
gen GPp50_PS_Par2 = .

gen GPp50_PSE_Par3 = .
gen GPp50_PS_Par3 = .

foreach part in 1 2 {
	foreach sex in 1 2 {
		foreach E in 0 1 {
			// Parity 1 (time since birth of first child) 
			stset durGPH if isparent==1, f(desGPH) origin(time ttfchild)
			stci if part==`part' & sex==`sex' & E == `E'
			replace GPp50_PSE_Par1 = `r(p50)' if part==`part' & sex==`sex' & E == `E'
			
			// Parity 2 (time since birth of first grandchild)
			stset durGPHnr2 if desGPH ==1, f(desGPHnr2) 
			stci if part==`part' & sex==`sex' & E == `E'
			replace GPp50_PSE_Par2 = `r(p50)' if part==`part' & sex==`sex' & E == `E'
			
			// Parity 3 (time since birth of second grandchild)
			stset durGPHnr3 if desGPHnr2 ==1, f(desGPHnr3) 
			stci if part==`part' & sex==`sex' & E == `E'
			replace GPp50_PSE_Par3 = `r(p50)' if part==`part' & sex==`sex' & E == `E'
			
			
		}
		// Parity 1 (time since birth of first child) 
		stset durGPH if isparent==1, f(desGPH) origin(time ttfchild)
		stci if part==`part' & sex==`sex' 
		replace GPp50_PS_Par1 = `r(p50)' if part==`part' & sex==`sex' 
			
		// Parity 2 (time since birth of first grandchild)
		stset durGPHnr2 if desGPH ==1, f(desGPHnr2) 
		stci if part==`part' & sex==`sex' 
		replace GPp50_PS_Par2 = `r(p50)' if part==`part' & sex==`sex' 
			
		// Parity 3 (time since birth of second grandchild)
		stset durGPHnr3 if desGPHnr2 ==1, f(desGPHnr3) 
		stci if part==`part' & sex==`sex' 
		replace GPp50_PS_Par3 = `r(p50)' if part==`part' & sex==`sex' 
			
	}
}

log using "${log}/Table_5.smcl", replace
// Data for table
// Parity 1

* mothers
table E part if sex==2, co(mean GPp50_PSE_Par1 sd GPp50_PSE_Par1) 
* fathers
table E part if sex==1, co(mean GPp50_PSE_Par1 sd GPp50_PSE_Par1) 
* total
table sex part, co(mean GPp50_PS_Par1 sd GPp50_PS_Par1) 

// Parity 2
* by education
table sex E part, co(mean GPp50_PSE_Par2 sd GPp50_PSE_Par2) 
* mothers
table  E part if sex==2, co(mean GPp50_PSE_Par2 sd GPp50_PSE_Par2) 
* fathers 
table  E part if sex==1, co(mean GPp50_PSE_Par2 sd GPp50_PSE_Par2) 
* total
table sex part, co(mean GPp50_PS_Par2 sd GPp50_PS_Par2) 

// Parity 3
* by education
table sex E part, co(mean GPp50_PSE_Par3 sd GPp50_PSE_Par3) 
* mothers
table  E part if sex==2, co(mean GPp50_PSE_Par3 sd GPp50_PSE_Par3) 
* fathers
table  E part if sex==1, co(mean GPp50_PSE_Par3 sd GPp50_PSE_Par3) 
* total
table sex part, co(mean GPp50_PS_Par3 sd GPp50_PS_Par3) 

log close

// important: needed for figure 2 below
sts list, failure by(part sex E) sav(log/gph-parity-1, replace)






/*----------------------------
	Figure 3
	Sequential transition to first time, second time, and third time grandparenthood by gender, part of Germany and educational level. Cumulated probability functions obtained by Kaplan-Meier estimation
----------------------------*/	
// condition on first time grandparenthood. 
// analyse transition to second grandchild. 

// Parity 1 (time since birth of first child
stset durGPH if isparent==1, f(desGPH) origin(time ttfchild)
sts list, failure by(part sex E) sav("${log}/gph-parity-1", replace)

// East men
stci if part==1 & sex==1, by(E) // 24, 26 – 25
// East women
stci if part==1 & sex==2, by(E) // 25, 27 – 25

// West men
stci if part==2 & sex==1, by(E) // 29, 33 – 31
// West women
stci if part==2 & sex==2, by(E) // 31, 33 – 31

// Parity 2
stset durGPHnr2 if desGPH ==1, f(desGPHnr2) // there are some cases with missing values (excluded)
sts list, failure by(part sex E) sav("${log}/gph-parity-2", replace)

stdes 
// EAST GERMANY
// men
stdes if part==1 & sex==1 & E==0
stdes if part==1 & sex==1 & E==1
sts list if part==1 & sex==1, by(E) fail at(2(2)12) compare
sts test E if part==1 & sex==1, logrank 
// export for local tests in excel
sts list if part==1 & sex==1, by(E) fail at(2(2)12) 


// women
stdes if part==1 & sex==2 & E==0
stdes if part==1 & sex==2 & E==1
sts list if part==1 & sex==2, by(E) fail at(2(2)12) compare
sts test E if part==1 & sex==2, logrank 
// export for local tests in excel
sts list if part==1 & sex==2, by(E) fail at(2(2)12) 

// WEST GERMANY
// men
stdes if part==2 & sex==1 & E==0
stdes if part==2 & sex==1 & E==1
sts list if part==2 & sex==1, by(E) fail at(2(2)12) compare
sts test E if part==2 & sex==1, logrank 
// export for local tests in excel
sts list if part==2 & sex==1, by(E) fail at(2(2)12)

// women
stdes if part==2 & sex==2 & E==0
stdes if part==2 & sex==2 & E==1
sts list if part==1 & sex==2, by(E) fail at(2(2)12) compare
sts test E if part==2 & sex==2, logrank 
// export for local tests in excel
sts list if part==2 & sex==2, by(E) fail at(2(2)12)

// East men
sts graph if part==1 & sex==1
stci if part==1 & sex==1, by(E) //4
// East women
stci if part==1 & sex==2, by(E) //4

// West men
sts graph if part==1 & sex==1
stci if part==2 & sex==1, by(E) // 3
// West women
stci if part==2 & sex==2, by(E) // 3


// Parity 3 or more
stset durGPHnr3 if desGPHnr2 ==1, f(desGPHnr3) // there are some cases with missing values (excluded)
sts list, failure by(part sex E) sav("${log}/gph-parity-3", replace)

// EAST GERMANY
// men
stdes if part==1 & sex==1 & E==0
stdes if part==1 & sex==1 & E==1
sts list if part==1 & sex==1, by(E) fail at(2(2)12) 
sts list if part==1 & sex==1, by(E) fail at(2(2)12) compare
sts test E if part==1 & sex==1, logrank 
// export for local tests in excel
sts list if part==1 & sex==1, by(E) fail at(2(2)12) 

// women
stdes if part==1 & sex==2 & E==0
stdes if part==1 & sex==2 & E==1
sts list if part==1 & sex==2, by(E) fail at(2(2)12) compare
sts test E if part==1 & sex==2, logrank 
// export for local tests in excel
sts list if part==1 & sex==2, by(E) fail at(2(2)12) 


// WEST GERMANY
// men
stdes if part==2 & sex==1 & E==0
stdes if part==2 & sex==1 & E==1
sts list if part==2 & sex==1, by(E) fail at(2(2)12) compare
sts test E if part==2 & sex==1, logrank 
// export for local tests in excel
sts list if part==2 & sex==1, by(E) fail at(2(2)12) 

// women
stdes if part==2 & sex==2 & E==0
stdes if part==2 & sex==2 & E==1
sts list if part==1 & sex==2, by(E) fail at(2(2)12) compare
sts test E if part==2 & sex==2, logrank 
// export for local tests in excel
sts list if part==2 & sex==2, by(E) fail at(2(2)12) 

// East men
sts graph if part==1 & sex==1
stci if part==1 & sex==1, by(E) //4
// East women
stci if part==1 & sex==2, by(E) //4

// West men
sts graph if part==1 & sex==1
stci if part==2 & sex==1, by(E) // 4
// West women
stci if part==2 & sex==2, by(E) // 5


stdes 


preserve
use "${log}/gph-parity-1", clear
gen parity = 1
append using "${log}/gph-parity-2"
replace parity = 2 if parity == .
append using "${log}/gph-parity-3"
replace parity = 3 if parity == .

egen group = group(part sex E), label

// East Germany - Men
twoway (line failure time if group== 1 & parity == 1 & inrange(time, 15,45), lcol(gs0) lpat(solid) c(l) sort) /// parity 1
	   (line failure time if group== 2 & parity == 1 & inrange(time, 15,45), lcol(gs0) lpat(shortdash) c(l) sort) /// parity 1
	   (line failure time if group== 1 & parity == 2 & inrange(time, 0,20), lcol(gs5) lpat(solid) c(l) sort) /// 2
	   (line failure time if group== 2 & parity == 2 & inrange(time, 0,20), lcol(gs5) lpat(shortdash) c(l) sort) /// 2
	   (line failure time if group== 1 & parity == 3 & inrange(time, 0,20), lcol(gs10) lpat(solid) c(l) sort) /// 3
	   (line failure time if group== 2 & parity == 3 & inrange(time, 0,20), lcol(gs10) lpat(shortdash) c(l) sort) /// 3
	   , ylabel(0 (.1) 1, labsize(small)) scheme(lean1) xlabel(0(5)45, labsize(small)) ///
			legend(lab(1 "Lower educated") /// 
				   lab(2 "Higher educated") /// 
				   size(vsmall) order(1 2) nobox region(color(none)) ring(0) pos(4)) ytitle("Estimated probability", size(small)) ///
				   title("East Germany - Men", size(medium)) xtitle("Time since fertility event (years)", size(small)) ///
				   yline(0, lpat(dot) lcol(gs8) lwidth(vthin)) ///
				   yline(.25, lpat(dot) lcol(gs8) lwidth(vthin)) ///
				   yline(.50, lpat(dot) lcol(gs8) lwidth(vthin)) ///
				   yline(.75, lpat(dot) lcol(gs8) lwidth(vthin)) ///
				   yline(1, lpat(dot) lcol(gs8) lwidth(vthin)) /// 
				   	text(.90 8 "Parity 2 grandchild" "(time since birth of 1st grandchild)", size(vsmall) col(gs5) justif(center)) ///
				   text(.56 12 "Parity 3 grandchild" "(time since birth of 2nd grandchild)", size(vsmall) col(gs10) justif(center)) ///
				   text(.40 30 "Parity 1 grandchild" "(time since birth of first child)", size(vsmall) col(gs0) justif(center)) ///
				   name(Parity_E_M, replace)
graph export "${log}/Parity_E_M.pdf", name(Parity_E_M) replace

// East Germany - Women
twoway (line failure time if group== 3 & parity == 1 & inrange(time, 15,45), lcol(gs0) lpat(solid) c(l) sort) /// parity 1
	   (line failure time if group== 4 & parity == 1 & inrange(time, 15,45), lcol(gs0) lpat(shortdash) c(l) sort) /// parity 1
	   (line failure time if group== 3 & parity == 2 & inrange(time, 0,20), lcol(gs5) lpat(solid) c(l) sort) /// 2
	   (line failure time if group== 4 & parity == 2 & inrange(time, 0,20), lcol(gs5) lpat(shortdash) c(l) sort) /// 2
	   (line failure time if group== 3 & parity == 3 & inrange(time, 0,20), lcol(gs10) lpat(solid) c(l) sort) /// 3
	   (line failure time if group== 4 & parity == 3 & inrange(time, 0,20), lcol(gs10) lpat(shortdash) c(l) sort) /// 3
	   , ylabel(0 (.1) 1, labsize(small)) scheme(lean1) xlabel(0(5)45, labsize(small)) ///
			legend(lab(1 "Lower educated") /// 
				   lab(2 "Higher educated") /// 
				   size(vsmall) order(1 2) nobox region(color(none)) ring(0) pos(4)) ytitle("Estimated probability", size(small)) ///
				   title("East Germany - Women", size(medium)) xtitle("Time since fertility event (years)", size(small)) ///
				   yline(0, lpat(dot) lcol(gs8) lwidth(vthin)) ///
				   yline(.25, lpat(dot) lcol(gs8) lwidth(vthin)) ///
				   yline(.50, lpat(dot) lcol(gs8) lwidth(vthin)) ///
				   yline(.75, lpat(dot) lcol(gs8) lwidth(vthin)) ///
				   yline(1, lpat(dot) lcol(gs8) lwidth(vthin)) /// 
				   	text(.89 8 "Parity 2 grandchild" "(time since birth of 1st grandchild)", size(vsmall) col(gs5) justif(center)) ///
				   text(.56 15 "Parity 3 grandchild" "(time since birth of 2nd grandchild)", size(vsmall) col(gs10) justif(center)) ///
				   text(.40 31 "Parity 1 grandchild" "(time since birth of first child)", size(vsmall) col(gs0) justif(center)) ///
				   name(Parity_E_W, replace)
graph export "${log}/Parity_E_W.pdf", name(Parity_E_W) replace

// West Germany - Men
twoway (line failure time if group== 5 & parity == 1 & inrange(time, 15,45), lcol(gs0) lpat(solid) c(l) sort) /// parity 1
	   (line failure time if group== 6 & parity == 1 & inrange(time, 15,45), lcol(gs0) lpat(shortdash) c(l) sort) /// parity 1
	   (line failure time if group== 5 & parity == 2 & inrange(time, 0,20), lcol(gs5) lpat(solid) c(l) sort) /// 2
	   (line failure time if group== 6 & parity == 2 & inrange(time, 0,20), lcol(gs5) lpat(shortdash) c(l) sort) /// 2
	   (line failure time if group== 5 & parity == 3 & inrange(time, 0,20), lcol(gs10) lpat(solid) c(l) sort) /// 3
	   (line failure time if group== 6 & parity == 3 & inrange(time, 0,20), lcol(gs10) lpat(shortdash) c(l) sort) /// 3
	   , ylabel(0 (.1) 1, labsize(small)) scheme(lean1) xlabel(0(5)45, labsize(small)) ///
			legend(lab(1 "Lower educated") /// 
				   lab(2 "Higher educated") /// 
				   size(vsmall) order(1 2) nobox region(color(none)) ring(0) pos(4)) ytitle("Estimated probability", size(small)) ///
				   title("West Germany - Men", size(medium)) xtitle("Time since fertility event (years)", size(small)) ///
				   yline(0, lpat(dot) lcol(gs8) lwidth(vthin)) ///
				   yline(.25, lpat(dot) lcol(gs8) lwidth(vthin)) ///
				   yline(.50, lpat(dot) lcol(gs8) lwidth(vthin)) ///
				   yline(.75, lpat(dot) lcol(gs8) lwidth(vthin)) ///
				   yline(1, lpat(dot) lcol(gs8) lwidth(vthin)) /// 
				   	text(.95 8 "Parity 2 grandchild" "(time since birth of 1st grandchild)", size(vsmall) col(gs5) justif(center)) ///
				   text(.56 12 "Parity 3 grandchild" "(time since birth of 2nd grandchild)", size(vsmall) col(gs10) justif(center)) ///
				   text(.40 37 "Parity 1 grandchild" "(time since birth of first child)", size(vsmall) col(gs0) justif(center)) ///
				   name(Parity_W_M, replace)
graph export "${log}/Parity_W_M.pdf", name(Parity_W_M) replace
				   
// West Germany - Women
twoway (line failure time if group== 7 & parity == 1 & inrange(time, 15,45), lcol(gs0) lpat(solid) c(l) sort) /// parity 1
	   (line failure time if group== 8 & parity == 1 & inrange(time, 15,45), lcol(gs0) lpat(shortdash) c(l) sort) /// parity 1
	   (line failure time if group== 7 & parity == 2 & inrange(time, 0,20), lcol(gs5) lpat(solid) c(l) sort) /// 2
	   (line failure time if group== 8 & parity == 2 & inrange(time, 0,20), lcol(gs5) lpat(shortdash) c(l) sort) /// 2
	   (line failure time if group== 7 & parity == 3 & inrange(time, 0,20), lcol(gs10) lpat(solid) c(l) sort) /// 3
	   (line failure time if group== 8 & parity == 3 & inrange(time, 0,20), lcol(gs10) lpat(shortdash) c(l) sort) /// 3
	   , ylabel(0 (.1) 1, labsize(small)) scheme(lean1) xlabel(0(5)45, labsize(small)) ///
			legend(lab(1 "Lower educated") /// 
				   lab(2 "Higher educated") /// 
				   size(vsmall) order(1 2) nobox region(color(none)) ring(0) pos(4)) ytitle("Estimated probability", size(small)) ///
				   title("West Germany - Women", size(medium)) xtitle("Time since fertility event (years)", size(small)) ///
				   yline(0, lpat(dot) lcol(gs8) lwidth(vthin)) ///
				   yline(.25, lpat(dot) lcol(gs8) lwidth(vthin)) ///
				   yline(.50, lpat(dot) lcol(gs8) lwidth(vthin)) ///
				   yline(.75, lpat(dot) lcol(gs8) lwidth(vthin)) ///
				   yline(1, lpat(dot) lcol(gs8) lwidth(vthin)) /// 
				   	text(.93 8 "Parity 2 grandchild" "(time since birth of 1st grandchild)", size(vsmall) col(gs5) justif(center)) ///
				   text(.56 13 "Parity 3 grandchild" "(time since birth of 2nd grandchild)", size(vsmall) col(gs10) justif(center)) ///
				   text(.40 38 "Parity 1 grandchild" "(time since birth of first child)", size(vsmall) col(gs0) justif(center)) ///
				   name(Parity_W_W, replace)
graph export "${log}/Parity_W_W.pdf", name(Parity_W_W) replace

				   
restore

graph combine Parity_E_W Parity_E_M ///
			  Parity_W_W Parity_W_M, ///
			  rows(2) iscale(*.8) scheme(lean1) ///
			  imargin(tiny) plotregion(margin(zero)) name(Figure2, replace)
graph export "${log}/Fig3.pdf", name(Figure2) replace
graph export "${log}/Fig3.eps", name(Figure2) replace fontface(Helvetica)






/*------------------------------------------------------------------------------
	III) Higher parity parenthood 
	
	APPENDIX FIGURE - Child parities
	(not shown in the paper)
------------------------------------------------------------------------------*/
// Parity 1 (time to first child since birth)
stset ttfchild , f(isparent) 
sts list, failure by(part sex E) sav(log/ph-parity-1, replace)
// Parity 2 (time to second child since birth of first child)
stset durPHnr2 if isparent==1, f(desPHnr2) 
sts list, failure by(part sex E) sav(log/ph-parity-2, replace)
// Parity 3 (time to third child since birth of second child)
stset durPHnr3 if desPHnr2==1, f(desPHnr3) 
sts list, failure by(part sex E) sav(log/ph-parity-3, replace)

preserve
use log/ph-parity-1, clear
gen parity = 1
append using log/ph-parity-2
replace parity = 2 if parity == .
append using log/ph-parity-3
replace parity = 3 if parity == .

egen group = group(part sex E), label

twoway (line failure time if group== 1 & parity == 1 & inrange(time, 0,45), lcol(gs0) lpat(solid) c(l) sort) /// parity 1
	   (line failure time if group== 2 & parity == 1 & inrange(time, 0,45), lcol(gs0) lpat(shortdash) c(l) sort) /// parity 1
	   (line failure time if group== 1 & parity == 2 & inrange(time, 0,25), lcol(gs5) lpat(solid) c(l) sort) /// 2
	   (line failure time if group== 2 & parity == 2 & inrange(time, 0,25), lcol(gs5) lpat(shortdash) c(l) sort) /// 2
	   (line failure time if group== 1 & parity == 3 & inrange(time, 0,25), lcol(gs10) lpat(solid) c(l) sort) /// 3
	   (line failure time if group== 2 & parity == 3 & inrange(time, 0,25), lcol(gs10) lpat(shortdash) c(l) sort) /// 3
	   , ylabel(0 (.1) 1) scheme(lean1) xlabel(0(5)45) ///
			legend(lab(1 "Lower educated") /// 
				   lab(2 "Higher educated") /// 
				   size(vsmall) order(1 2) nobox region(color(none)) ring(0) pos(4)) ytitle("Estimated probability") ///
				   title("East Germany - Men") xtitle("Time since fertility event (years)") ///
				   yline(0, lpat(dot) lcol(gs8) lwidth(vthin)) ///
				   yline(.25, lpat(dot) lcol(gs8) lwidth(vthin)) ///
				   yline(.50, lpat(dot) lcol(gs8) lwidth(vthin)) ///
				   yline(.75, lpat(dot) lcol(gs8) lwidth(vthin)) ///
				   yline(1, lpat(dot) lcol(gs8) lwidth(vthin)) /// 
				   	text(.80 8 "Having 2nd child" "(time since birth of 1st child)", size(vsmall) col(gs5) justif(center)) ///
				   text(.43 11 "Having 3rd child" "(time since birth of 2nd child)", size(vsmall) col(gs10) justif(center)) ///
				   text(.50 31 "Having a child" "(time since birth)", size(vsmall) col(gs0) justif(center)) ///
				   name(Parity_E_M, replace)
twoway (line failure time if group== 5 & parity == 1 & inrange(time, 0,45), lcol(gs0) lpat(solid) c(l) sort) /// parity 1
	   (line failure time if group== 6 & parity == 1 & inrange(time, 0,45), lcol(gs0) lpat(shortdash) c(l) sort) /// parity 1
	   (line failure time if group== 5 & parity == 2 & inrange(time, 0,25), lcol(gs5) lpat(solid) c(l) sort) /// 2
	   (line failure time if group== 6 & parity == 2 & inrange(time, 0,25), lcol(gs5) lpat(shortdash) c(l) sort) /// 2
	   (line failure time if group== 5 & parity == 3 & inrange(time, 0,25), lcol(gs10) lpat(solid) c(l) sort) /// 3
	   (line failure time if group== 6 & parity == 3 & inrange(time, 0,25), lcol(gs10) lpat(shortdash) c(l) sort) /// 3
	   , ylabel(0 (.1) 1) scheme(lean1) xlabel(0(5)45) ///
			legend(lab(1 "Lower educated") /// 
				   lab(2 "Higher educated") /// 
				   size(vsmall) order(1 2) nobox region(color(none)) ring(0) pos(4)) ytitle("Estimated probability") ///
				   title("West Germany - Men") xtitle("Time since fertility event (years)") ///
				   yline(0, lpat(dot) lcol(gs8) lwidth(vthin)) ///
				   yline(.25, lpat(dot) lcol(gs8) lwidth(vthin)) ///
				   yline(.50, lpat(dot) lcol(gs8) lwidth(vthin)) ///
				   yline(.75, lpat(dot) lcol(gs8) lwidth(vthin)) ///
				   yline(1, lpat(dot) lcol(gs8) lwidth(vthin)) /// 
				   	text(.80 8 "Having 2nd child" "(time since birth of 1st child)", size(vsmall) col(gs5) justif(center)) ///
				   text(.43 11 "Having 3rd child" "(time since birth of 2nd child)", size(vsmall) col(gs10) justif(center)) ///
				   text(.50 31 "Having a child" "(time since birth)", size(vsmall) col(gs0) justif(center)) ///
				   name(Parity_W_M, replace)
twoway (line failure time if group== 3 & parity == 1 & inrange(time, 0,45), lcol(gs0) lpat(solid) c(l) sort) /// parity 1
	   (line failure time if group== 4 & parity == 1 & inrange(time, 0,45), lcol(gs0) lpat(shortdash) c(l) sort) /// parity 1
	   (line failure time if group== 3 & parity == 2 & inrange(time, 0,25), lcol(gs5) lpat(solid) c(l) sort) /// 2
	   (line failure time if group== 4 & parity == 2 & inrange(time, 0,25), lcol(gs5) lpat(shortdash) c(l) sort) /// 2
	   (line failure time if group== 3 & parity == 3 & inrange(time, 0,25), lcol(gs10) lpat(solid) c(l) sort) /// 3
	   (line failure time if group== 4 & parity == 3 & inrange(time, 0,25), lcol(gs10) lpat(shortdash) c(l) sort) /// 3
	   , ylabel(0 (.1) 1) scheme(lean1) xlabel(0(5)45) ///
			legend(lab(1 "Lower educated") /// 
				   lab(2 "Higher educated") /// 
				   size(vsmall) order(1 2) nobox region(color(none)) ring(0) pos(4)) ytitle("Estimated probability") ///
				   title("East Germany - Women") xtitle("Time since fertility event (years)") ///
				   yline(0, lpat(dot) lcol(gs8) lwidth(vthin)) ///
				   yline(.25, lpat(dot) lcol(gs8) lwidth(vthin)) ///
				   yline(.50, lpat(dot) lcol(gs8) lwidth(vthin)) ///
				   yline(.75, lpat(dot) lcol(gs8) lwidth(vthin)) ///
				   yline(1, lpat(dot) lcol(gs8) lwidth(vthin)) /// 
				   	text(.78 8 "Having 2nd child" "(time since birth of 1st child)", size(vsmall) col(gs5) justif(center)) ///
				   text(.35 11 "Having 3rd child" "(time since birth of 2nd child)", size(vsmall) col(gs10) justif(center)) ///
				   text(.50 31 "Having a child" "(time since birth)", size(vsmall) col(gs0) justif(center)) ///
				   name(Parity_E_W, replace)
twoway (line failure time if group== 7 & parity == 1 & inrange(time, 0,45), lcol(gs0) lpat(solid) c(l) sort) /// parity 1
	   (line failure time if group== 8 & parity == 1 & inrange(time, 0,45), lcol(gs0) lpat(shortdash) c(l) sort) /// parity 1
	   (line failure time if group== 7 & parity == 2 & inrange(time, 0,25), lcol(gs5) lpat(solid) c(l) sort) /// 2
	   (line failure time if group== 8 & parity == 2 & inrange(time, 0,25), lcol(gs5) lpat(shortdash) c(l) sort) /// 2
	   (line failure time if group== 7 & parity == 3 & inrange(time, 0,25), lcol(gs10) lpat(solid) c(l) sort) /// 3
	   (line failure time if group== 8 & parity == 3 & inrange(time, 0,25), lcol(gs10) lpat(shortdash) c(l) sort) /// 3
	   , ylabel(0 (.1) 1) scheme(lean1) xlabel(0(5)45) ///
			legend(lab(1 "Lower educated") /// 
				   lab(2 "Higher educated") /// 
				   size(vsmall) order(1 2) nobox region(color(none)) ring(0) pos(4)) ytitle("Estimated probability") ///
				   title("West Germany - Women") xtitle("Time since fertility event (years)") ///
				   yline(0, lpat(dot) lcol(gs8) lwidth(vthin)) ///
				   yline(.25, lpat(dot) lcol(gs8) lwidth(vthin)) ///
				   yline(.50, lpat(dot) lcol(gs8) lwidth(vthin)) ///
				   yline(.75, lpat(dot) lcol(gs8) lwidth(vthin)) ///
				   yline(1, lpat(dot) lcol(gs8) lwidth(vthin)) /// 
				   	text(.78 8 "Having 2nd child" "(time since birth of 1st child)", size(vsmall) col(gs5) justif(center)) ///
				   text(.42 11 "Having 3rd child" "(time since birth of 2nd child)", size(vsmall) col(gs10) justif(center)) ///
				   text(.50 31 "Having a child" "(time since birth)", size(vsmall) col(gs0) justif(center)) ///
				   name(Parity_W_W, replace)	
				   
grc1leg  Parity_E_M Parity_W_M Parity_E_W Parity_W_W, ///
		 rows(2) iscale(*.7) imargin(tiny) note("Kaplan-Meier estimates, smoothed.", size(vsmall))	name(Figure_A1, replace)		///
		 graphregion(color(white)) scheme(lean1) plotregion(margin(zero))
graph export "${log}/Figure_A1.pdf", name(Figure_A1) replace
